"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class DataSourceProperties(str, Enum):
    r"""Names of data source fields supported for filtering/sorting on list endpoint."""

    NAME = "name"
    DESCRIPTION = "description"
    LABELS = "labels"
    CHUNK = "chunk"
    CHUNK_DELIMITER = "chunk_delimiter"
    UPDATED_AT = "updated_at"
    LAST_UPDATED_BY = "last_updated_by"
