"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class InsightsProperties(str, Enum):
    ID = "id"
    SESSION_ID = "session_id"
    UPLOAD_FILE_ID = "upload_file_id"
    WORKFLOW_ID = "workflow_id"
    UPLOAD_FOLDER_ID = "upload_folder_id"
    INSIGHT_KEY = "insight_key"
    INSIGHT_TOOL_ID = "insight_tool_id"
