"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from syllable_sdk.types import BaseModel
from typing_extensions import TypedDict


class TwilioNumberUpdateResponseTypedDict(TypedDict):
    r"""Response model for updating a Twilio number and associating it with a channel."""

    phone_number: str
    r"""The updated Twilio phone number"""


class TwilioNumberUpdateResponse(BaseModel):
    r"""Response model for updating a Twilio number and associating it with a channel."""

    phone_number: str
    r"""The updated Twilio phone number"""
