"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from syllable_sdk.types import BaseModel
from typing_extensions import TypedDict


class TwilioChannelConfigCreateTypedDict(TypedDict):
    r"""Twilio channel config information."""

    account_sid: str
    r"""SID of the Twilio account"""
    auth_token: str
    r"""The Twilio auth token"""


class TwilioChannelConfigCreate(BaseModel):
    r"""Twilio channel config information."""

    account_sid: str
    r"""SID of the Twilio account"""

    auth_token: str
    r"""The Twilio auth token"""
