"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class DialogRole(str, Enum):
    r"""Role of dialog"""

    AGENT = "agent"
    USER = "user"
