"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .twiliophonenumber import TwilioPhoneNumber, TwilioPhoneNumberTypedDict
from syllable_sdk.types import BaseModel
from typing import List
from typing_extensions import TypedDict


class TwilioListNumbersResponseTypedDict(TypedDict):
    r"""Response model for a list of Twilio phone numbers"""

    phone_numbers: List[TwilioPhoneNumberTypedDict]
    r"""List of phone numbers."""


class TwilioListNumbersResponse(BaseModel):
    r"""Response model for a list of Twilio phone numbers"""

    phone_numbers: List[TwilioPhoneNumber]
    r"""List of phone numbers."""
