"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class EventProperties(str, Enum):
    TIMESTAMP = "timestamp"
    SESSION_ID = "session_id"
    CONVERSATION_ID = "conversation_id"
    SOURCE = "source"
    SOURCE_ID = "source_id"
    CATEGORY = "category"
    TYPE = "type"
    USER_ID = "user_id"
    DESCRIPTION = "description"
    ATTRIBUTES = "attributes"
