"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class UserProperties(str, Enum):
    r"""Names of user fields supported for filtering/sorting on list endpoint."""

    EMAIL = "email"
    FIRST_NAME = "first_name"
    LAST_NAME = "last_name"
    ROLE_ID = "role_id"
    ROLE_NAME = "role_name"
    EMAIL_FIRST_NAME_LAST_NAME = "email_first_name_last_name"
    ACTIVITY_STATUS = "activity_status"
    LAST_UPDATED = "last_updated"
