"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class AgentWaitSound(str, Enum):
    r"""Wait sounds supported by agents."""

    NO_SOUND = "No Sound"
    KEYBOARD_1 = "Keyboard 1"
    KEYBOARD_2 = "Keyboard 2"
    CALL_CENTER = "Call Center"
