"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from syllable_sdk.types import BaseModel
from typing_extensions import TypedDict


class DialogMessageTypedDict(TypedDict):
    text: str
    r"""Dialog message text"""


class DialogMessage(BaseModel):
    text: str
    r"""Dialog message text"""
