"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from syllable_sdk.types import BaseModel
from typing_extensions import TypedDict


class InsightWorkflowEstimateTypedDict(TypedDict):
    r"""Response model for an insight workflow."""

    backfill_count: int
    r"""Number of extant calls that will be processed by the workflow"""
    backfill_duration: float
    r"""Estimated duration of the calls that will be processed by the workflow"""
    estimated_daily_count: int
    r"""Estimated number of calls that will be processed by the workflow daily"""
    estimated_daily_duration: float
    r"""Estimated duration of the calls that will be processed by the workflow daily"""
    estimated_daily_cost: float
    r"""Estimated cost of the calls that will be processed by the workflow daily"""
    estimated_backfill_cost: float
    r"""Estimated cost of the backfill of the calls that will be processed by the workflow"""


class InsightWorkflowEstimate(BaseModel):
    r"""Response model for an insight workflow."""

    backfill_count: int
    r"""Number of extant calls that will be processed by the workflow"""

    backfill_duration: float
    r"""Estimated duration of the calls that will be processed by the workflow"""

    estimated_daily_count: int
    r"""Estimated number of calls that will be processed by the workflow daily"""

    estimated_daily_duration: float
    r"""Estimated duration of the calls that will be processed by the workflow daily"""

    estimated_daily_cost: float
    r"""Estimated cost of the calls that will be processed by the workflow daily"""

    estimated_backfill_cost: float
    r"""Estimated cost of the backfill of the calls that will be processed by the workflow"""
