"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from syllable_sdk.types import BaseModel
from typing import Dict
from typing_extensions import TypedDict


class CommunicationRequestTypedDict(TypedDict):
    reference_id: str
    r"""ID for target outreach (unique within batch)"""
    target: str
    r"""Target phone number"""
    request_variables: Dict[str, str]
    r"""Variables for request"""


class CommunicationRequest(BaseModel):
    reference_id: str
    r"""ID for target outreach (unique within batch)"""

    target: str
    r"""Target phone number"""

    request_variables: Dict[str, str]
    r"""Variables for request"""
