"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from syllable_sdk.types import BaseModel
from typing_extensions import TypedDict


class TwilioNumberAddResponseTypedDict(TypedDict):
    r"""Response model for purchasing a Twilio number and associating it with a channel."""

    phone_number: str
    r"""The purchased Twilio phone number"""


class TwilioNumberAddResponse(BaseModel):
    r"""Response model for purchasing a Twilio number and associating it with a channel."""

    phone_number: str
    r"""The purchased Twilio phone number"""
