"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class CampaignProperties(str, Enum):
    ID = "id"
    CAMPAIGN_NAME = "campaign_name"
    CAMPAIGN_VARIABLES = "campaign_variables"
    DAILY_START_TIME = "daily_start_time"
    DAILY_END_TIME = "daily_end_time"
    SOURCE = "source"
    CALLER_ID = "caller_id"
    UPDATED_AT = "updated_at"
    LABEL = "label"
    LABELS = "labels"
