"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from syllable_sdk.types import BaseModel
from typing_extensions import TypedDict


class LanguageGroupAgentInfoTypedDict(TypedDict):
    r"""Information about an agent linked to a language group."""

    id: int
    r"""The ID of the agent"""
    name: str
    r"""The name of the agent"""


class LanguageGroupAgentInfo(BaseModel):
    r"""Information about an agent linked to a language group."""

    id: int
    r"""The ID of the agent"""

    name: str
    r"""The name of the agent"""
