"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class LoginType(str, Enum):
    r"""The type of login to use for the user."""

    GOOGLE = "google"
    USERNAME_AND_PASSWORD = "username_and_password"
