"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class AgentVoiceDisplayName(str, Enum):
    r"""Display names of voices that Syllable supports."""

    ACHERNAR_ENGLISH_ = "Achernar (English)"
    ACHERNAR_KOREAN_ = "Achernar (Korean)"
    ACHERNAR_MANDARIN_ = "Achernar (Mandarin)"
    ACHERNAR_SPANISH_ = "Achernar (Spanish)"
    ACHERNAR_THAI_ = "Achernar (Thai)"
    ACHERNAR_VIETNAMESE_ = "Achernar (Vietnamese)"
    ALICE = "Alice"
    ALLOY = "Alloy"
    AOEDE_ENGLISH_ = "Aoede (English)"
    AOEDE_KOREAN_ = "Aoede (Korean)"
    AOEDE_MANDARIN_ = "Aoede (Mandarin)"
    AOEDE_SPANISH_ = "Aoede (Spanish)"
    AOEDE_THAI_ = "Aoede (Thai)"
    AOEDE_VIETNAMESE_ = "Aoede (Vietnamese)"
    ASH = "Ash"
    BILL = "Bill"
    BRIAN = "Brian"
    CALLIRRHOE_ENGLISH_ = "Callirrhoe (English)"
    CALLIRRHOE_KOREAN_ = "Callirrhoe (Korean)"
    CALLIRRHOE_MANDARIN_ = "Callirrhoe (Mandarin)"
    CALLIRRHOE_SPANISH_ = "Callirrhoe (Spanish)"
    CALLIRRHOE_THAI_ = "Callirrhoe (Thai)"
    CALLIRRHOE_VIETNAMESE_ = "Callirrhoe (Vietnamese)"
    CALLUM = "Callum"
    CHARLIE = "Charlie"
    CHARLOTTE = "Charlotte"
    CHARON_ENGLISH_ = "Charon (English)"
    CHARON_KOREAN_ = "Charon (Korean)"
    CHARON_MANDARIN_ = "Charon (Mandarin)"
    CHARON_SPANISH_ = "Charon (Spanish)"
    CHARON_THAI_ = "Charon (Thai)"
    CHARON_VIETNAMESE_ = "Charon (Vietnamese)"
    CHRIS = "Chris"
    CMN_TW_WAVENET_A = "cmn-TW-Wavenet-A"
    CORAL = "Coral"
    DANIEL = "Daniel"
    ECHO = "Echo"
    EN_US_NEURAL2_D = "en-US-Neural2-D"
    EN_US_NEURAL2_F = "en-US-Neural2-F"
    EN_US_NEURAL2_J = "en-US-Neural2-J"
    EN_US_STUDIO_O = "en-US-Studio-O"
    ERIC = "Eric"
    ES_US_NEURAL2_A = "es-US-Neural2-A"
    ES_US_NEURAL2_B = "es-US-Neural2-B"
    FABLE = "Fable"
    FENRIR_ENGLISH_ = "Fenrir (English)"
    FENRIR_KOREAN_ = "Fenrir (Korean)"
    FENRIR_MANDARIN_ = "Fenrir (Mandarin)"
    FENRIR_SPANISH_ = "Fenrir (Spanish)"
    FENRIR_THAI_ = "Fenrir (Thai)"
    FENRIR_VIETNAMESE_ = "Fenrir (Vietnamese)"
    GEORGE = "George"
    JESSICA = "Jessica"
    KO_KR_NEURAL2_A = "ko-KR-Neural2-A"
    KORE_ENGLISH_ = "Kore (English)"
    KORE_KOREAN_ = "Kore (Korean)"
    KORE_MANDARIN_ = "Kore (Mandarin)"
    KORE_SPANISH_ = "Kore (Spanish)"
    KORE_THAI_ = "Kore (Thai)"
    KORE_VIETNAMESE_ = "Kore (Vietnamese)"
    LAURA = "Laura"
    LEDA_ENGLISH_ = "Leda (English)"
    LEDA_KOREAN_ = "Leda (Korean)"
    LEDA_MANDARIN_ = "Leda (Mandarin)"
    LEDA_SPANISH_ = "Leda (Spanish)"
    LEDA_THAI_ = "Leda (Thai)"
    LEDA_VIETNAMESE_ = "Leda (Vietnamese)"
    LIAM = "Liam"
    LILY = "Lily"
    MATILDA = "Matilda"
    NOVA = "Nova"
    ONYX = "Onyx"
    ORUS_ENGLISH_ = "Orus (English)"
    ORUS_KOREAN_ = "Orus (Korean)"
    ORUS_MANDARIN_ = "Orus (Mandarin)"
    ORUS_SPANISH_ = "Orus (Spanish)"
    ORUS_THAI_ = "Orus (Thai)"
    ORUS_VIETNAMESE_ = "Orus (Vietnamese)"
    PUCK_ENGLISH_ = "Puck (English)"
    PUCK_KOREAN_ = "Puck (Korean)"
    PUCK_MANDARIN_ = "Puck (Mandarin)"
    PUCK_SPANISH_ = "Puck (Spanish)"
    PUCK_THAI_ = "Puck (Thai)"
    PUCK_VIETNAMESE_ = "Puck (Vietnamese)"
    RIVER = "River"
    ROGER = "Roger"
    SARAH = "Sarah"
    SAGE = "Sage"
    SHIMMER = "Shimmer"
    UMBRIEL_ENGLISH_ = "Umbriel (English)"
    UMBRIEL_KOREAN_ = "Umbriel (Korean)"
    UMBRIEL_MANDARIN_ = "Umbriel (Mandarin)"
    UMBRIEL_SPANISH_ = "Umbriel (Spanish)"
    UMBRIEL_THAI_ = "Umbriel (Thai)"
    UMBRIEL_VIETNAMESE_ = "Umbriel (Vietnamese)"
    VINDEMIATRIX_ENGLISH_ = "Vindemiatrix (English)"
    VINDEMIATRIX_KOREAN_ = "Vindemiatrix (Korean)"
    VINDEMIATRIX_MANDARIN_ = "Vindemiatrix (Mandarin)"
    VINDEMIATRIX_SPANISH_ = "Vindemiatrix (Spanish)"
    VINDEMIATRIX_THAI_ = "Vindemiatrix (Thai)"
    VINDEMIATRIX_VIETNAMESE_ = "Vindemiatrix (Vietnamese)"
    VI_VN_NEURAL2_A = "vi-VN-Neural2-A"
    WILL = "Will"
    YUE_HK_STANDARD_C = "yue-HK-Standard-C"
    ZEPHYR_ENGLISH_ = "Zephyr (English)"
    ZEPHYR_KOREAN_ = "Zephyr (Korean)"
    ZEPHYR_MANDARIN_ = "Zephyr (Mandarin)"
    ZEPHYR_SPANISH_ = "Zephyr (Spanish)"
    ZEPHYR_THAI_ = "Zephyr (Thai)"
    ZEPHYR_VIETNAMESE_ = "Zephyr (Vietnamese)"
