"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class SessionProperties(str, Enum):
    r"""Names of session fields supported for filtering/sorting on list endpoint."""

    TIMESTAMP = "timestamp"
    SESSION_ID = "session_id"
    CONVERSATION_ID = "conversation_id"
    CHANNEL_MANAGER_SERVICE = "channel_manager_service"
    CHANNEL_MANAGER_TYPE = "channel_manager_type"
    CHANNEL_MANAGER_SID = "channel_manager_sid"
    AGENT_TYPE = "agent_type"
    AGENT_ID = "agent_id"
    AGENT_NAME = "agent_name"
    PROMPT_ID = "prompt_id"
    PROMPT_NAME = "prompt_name"
    SOURCE = "source"
    TARGET = "target"
    DURATION = "duration"
    IS_LEGACY = "is_legacy"
    IS_TEST = "is_test"
