"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class BatchProperties(str, Enum):
    BATCH_ID = "batch_id"
    CAMPAIGN_ID = "campaign_id"
    STATUS = "status"
    EXPIRES_ON = "expires_on"
    LAST_UPDATED_AT = "last_updated_at"
