"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class AgentProperties(str, Enum):
    r"""Names of agent fields supported for filtering/sorting on list endpoint."""

    ID = "id"
    NAME = "name"
    NAME_EXACT = "name_exact"
    DESCRIPTION = "description"
    LABEL = "label"
    LABELS = "labels"
    NAME_DESCRIPTION = "name_description"
    TYPE = "type"
    TIMEZONE = "timezone"
    PROMPT_ID = "prompt_id"
    PROMPT_ID_LIST = "prompt_id_list"
    CUSTOM_MESSAGE_ID = "custom_message_id"
    LANGUAGES = "languages"
    VARIABLES = "variables"
    PROMPT_TOOL_DEFAULTS = "prompt_tool_defaults"
    TOOL_HEADERS = "tool_headers"
    UPDATED_AT = "updated_at"
    LAST_UPDATED_BY = "last_updated_by"
