"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from syllable_sdk.types import BaseModel
from typing_extensions import TypedDict


class TwilioNumberAddRequestTypedDict(TypedDict):
    r"""Request model for purchasing a Twilio number and associating it with a channel."""

    friendly_name: str
    r"""Friendly name for the Twilio number"""
    area_code: str
    r"""Area code for the Twilio number"""


class TwilioNumberAddRequest(BaseModel):
    r"""Request model for purchasing a Twilio number and associating it with a channel."""

    friendly_name: str
    r"""Friendly name for the Twilio number"""

    area_code: str
    r"""Area code for the Twilio number"""
