"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class ToolAuthType(str, Enum):
    BASIC = "basic"
    BEARER = "bearer"
    CUSTOM_HEADERS = "custom_headers"
    OAUTH2 = "oauth2"
