"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class InsightsUploadFileProperties(str, Enum):
    FILENAME = "filename"
    FILENAME_EXACT = "filename_exact"
    CALL_ID = "call_id"
    AGENT_NUMBER = "agent_number"
    CUSTOMER_NUMBER = "customer_number"
    DURATION = "duration"
    START_TIME = "start_time"
    END_TIME = "end_time"
    CREATED_AT = "created_at"
