"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class IncidentProperties(str, Enum):
    r"""Names of agent fields supported for filtering/sorting on list endpoint."""

    ID = "id"
    DESCRIPTION = "description"
    IMPACT_CATEGORY = "impact_category"
    SESSIONS_IMPACTED = "sessions_impacted"
    MARKDOWN = "markdown"
    CREATED_AT = "created_at"
    UPDATED_AT = "updated_at"
    ORGANIZATION_ID = "organization_id"
    SUB_ORGANIZATION_ID = "sub_organization_id"
    START_DATETIME = "start_datetime"
    END_DATETIME = "end_datetime"
    RESOLUTION_DATETIME = "resolution_datetime"
