"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from syllable_sdk.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class ToolOptionsTypedDict(TypedDict):
    r"""The options for a tool call."""

    propagate_tool_result: NotRequired[bool]
    r"""Whether the tool call result should be propagated to the caller."""


class ToolOptions(BaseModel):
    r"""The options for a tool call."""

    propagate_tool_result: Optional[bool] = False
    r"""Whether the tool call result should be propagated to the caller."""
