"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class ChannelServices(str, Enum):
    r"""The communication service for a channel."""

    SIP = "sip"
    TWILIO = "twilio"
    EMAIL = "email"
    WEBCHAT = "webchat"
