"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from .agentresponse import AgentResponse, AgentResponseTypedDict
from .channeltargetresponse import ChannelTargetResponse, ChannelTargetResponseTypedDict
from typing import TYPE_CHECKING
from importlib import import_module
import builtins
import sys

if TYPE_CHECKING:
    from .agent_deleteop import AgentDeleteRequest, AgentDeleteRequestTypedDict
    from .agent_get_by_idop import AgentGetByIDRequest, AgentGetByIDRequestTypedDict
    from .agent_listop import AgentListRequest, AgentListRequestTypedDict
    from .agentcreate import AgentCreate, AgentCreateTypedDict
    from .agentlanguage import AgentLanguage, AgentLanguageTypedDict
    from .agentproperties import AgentProperties
    from .agentsttprovider import AgentSttProvider
    from .agenttooldefaults import AgentToolDefaults, AgentToolDefaultsTypedDict
    from .agenttoolfielddefault import (
        AgentToolFieldDefault,
        AgentToolFieldDefaultTypedDict,
    )
    from .agentupdate import AgentUpdate, AgentUpdateTypedDict
    from .agentvoice import AgentVoice, AgentVoiceTypedDict
    from .agentvoicedisplayname import AgentVoiceDisplayName
    from .agentvoicegender import AgentVoiceGender
    from .agentvoicemodel import AgentVoiceModel
    from .agentvoicevarname import AgentVoiceVarName
    from .agentwaitsound import AgentWaitSound
    from .available_targetsop import (
        AvailableTargetsRequest,
        AvailableTargetsRequestTypedDict,
    )
    from .availabletarget import AvailableTarget, AvailableTargetTypedDict
    from .availabletargetproperties import AvailableTargetProperties
    from .batchdetails import BatchDetails, BatchDetailsTypedDict
    from .batchproperties import BatchProperties
    from .batchstatus import BatchStatus
    from .body_insights_folder_upload_file import (
        BodyInsightsFolderUploadFile,
        BodyInsightsFolderUploadFileFile,
        BodyInsightsFolderUploadFileFileTypedDict,
        BodyInsightsFolderUploadFileTypedDict,
    )
    from .body_organizations_create import (
        BodyOrganizationsCreate,
        BodyOrganizationsCreateLogo,
        BodyOrganizationsCreateLogoTypedDict,
        BodyOrganizationsCreateTypedDict,
    )
    from .body_organizations_delete import (
        BodyOrganizationsDelete,
        BodyOrganizationsDeleteTypedDict,
    )
    from .body_organizations_update import (
        BodyOrganizationsUpdate,
        BodyOrganizationsUpdateLogo,
        BodyOrganizationsUpdateLogoTypedDict,
        BodyOrganizationsUpdateTypedDict,
    )
    from .body_outbound_batch_delete import (
        BodyOutboundBatchDelete,
        BodyOutboundBatchDeleteTypedDict,
    )
    from .body_outbound_batch_upload import (
        BodyOutboundBatchUpload,
        BodyOutboundBatchUploadFile,
        BodyOutboundBatchUploadFileTypedDict,
        BodyOutboundBatchUploadTypedDict,
    )
    from .campaignproperties import CampaignProperties
    from .channel import Channel, ChannelTypedDict
    from .channel_targets_createop import (
        ChannelTargetsCreateRequest,
        ChannelTargetsCreateRequestTypedDict,
    )
    from .channel_targets_deleteop import (
        ChannelTargetsDeleteRequest,
        ChannelTargetsDeleteRequestTypedDict,
    )
    from .channel_targets_get_by_idop import (
        ChannelTargetsGetByIDRequest,
        ChannelTargetsGetByIDRequestTypedDict,
    )
    from .channel_targets_listop import (
        ChannelTargetsListRequest,
        ChannelTargetsListRequestTypedDict,
    )
    from .channel_targets_updateop import (
        ChannelTargetsUpdateRequest,
        ChannelTargetsUpdateRequestTypedDict,
    )
    from .channelconfigview import ChannelConfigView, ChannelConfigViewTypedDict
    from .channelproperties import ChannelProperties
    from .channels_listop import ChannelsListRequest, ChannelsListRequestTypedDict
    from .channels_twilio_get_by_idop import (
        ChannelsTwilioGetByIDRequest,
        ChannelsTwilioGetByIDRequestTypedDict,
    )
    from .channels_twilio_numbers_addop import (
        ChannelsTwilioNumbersAddRequest,
        ChannelsTwilioNumbersAddRequestTypedDict,
    )
    from .channels_twilio_numbers_listop import (
        ChannelsTwilioNumbersListRequest,
        ChannelsTwilioNumbersListRequestTypedDict,
    )
    from .channels_twilio_numbers_updateop import (
        ChannelsTwilioNumbersUpdateRequest,
        ChannelsTwilioNumbersUpdateRequestTypedDict,
    )
    from .channelservices import ChannelServices
    from .channeltargetcreaterequest import (
        ChannelTargetCreateRequest,
        ChannelTargetCreateRequestTypedDict,
    )
    from .channeltargetproperties import ChannelTargetProperties
    from .channeltargetupdaterequest import (
        ChannelTargetUpdateRequest,
        ChannelTargetUpdateRequestTypedDict,
    )
    from .communicationbatch import CommunicationBatch, CommunicationBatchTypedDict
    from .communicationbatchinput import (
        CommunicationBatchInput,
        CommunicationBatchInputTypedDict,
    )
    from .communicationbatchupdate import (
        CommunicationBatchUpdate,
        CommunicationBatchUpdateTypedDict,
    )
    from .communicationrequest import (
        CommunicationRequest,
        CommunicationRequestTypedDict,
    )
    from .communicationrequestresult import (
        CommunicationRequestResult,
        CommunicationRequestResultTypedDict,
        Insights,
        InsightsTypedDict,
    )
    from .conversation import Conversation, ConversationTypedDict
    from .conversationproperties import ConversationProperties
    from .conversations_listop import (
        ConversationsListRequest,
        ConversationsListRequestTypedDict,
    )
    from .createtakeoutresponse import (
        CreateTakeoutResponse,
        CreateTakeoutResponseTypedDict,
    )
    from .custom_message_get_by_idop import (
        CustomMessageGetByIDRequest,
        CustomMessageGetByIDRequestTypedDict,
    )
    from .custom_messages_deleteop import (
        CustomMessagesDeleteRequest,
        CustomMessagesDeleteRequestTypedDict,
    )
    from .custom_messages_listop import (
        CustomMessagesListRequest,
        CustomMessagesListRequestTypedDict,
    )
    from .custommessagecreaterequest import (
        CustomMessageCreateRequest,
        CustomMessageCreateRequestTypedDict,
    )
    from .custommessageproperties import CustomMessageProperties
    from .custommessageresponse import (
        CustomMessageResponse,
        CustomMessageResponseTypedDict,
    )
    from .custommessagerule import CustomMessageRule, CustomMessageRuleTypedDict
    from .custommessageupdaterequest import (
        CustomMessageUpdateRequest,
        CustomMessageUpdateRequestTypedDict,
    )
    from .dashboard import Dashboard, DashboardTypedDict
    from .dashboardproperties import DashboardProperties
    from .dashboardresponse import DashboardResponse, DashboardResponseTypedDict
    from .dashboardtokenresponse import (
        DashboardTokenResponse,
        DashboardTokenResponseTypedDict,
    )
    from .data_sources_deleteop import (
        DataSourcesDeleteRequest,
        DataSourcesDeleteRequestTypedDict,
    )
    from .data_sources_get_by_idop import (
        DataSourcesGetByIDRequest,
        DataSourcesGetByIDRequestTypedDict,
    )
    from .data_sources_listop import (
        DataSourcesListRequest,
        DataSourcesListRequestTypedDict,
    )
    from .datasourcecreaterequest import (
        DataSourceCreateRequest,
        DataSourceCreateRequestTypedDict,
    )
    from .datasourcedetailresponse import (
        DataSourceDetailResponse,
        DataSourceDetailResponseTypedDict,
    )
    from .datasourcemetadataresponse import (
        DataSourceMetadataResponse,
        DataSourceMetadataResponseTypedDict,
    )
    from .datasourceproperties import DataSourceProperties
    from .datasourceupdaterequest import (
        DataSourceUpdateRequest,
        DataSourceUpdateRequestTypedDict,
    )
    from .dayofweek import DayOfWeek
    from .daysofweek import DaysOfWeek
    from .dialogmessage import DialogMessage, DialogMessageTypedDict
    from .dialogrole import DialogRole
    from .dialogtoolcall import DialogToolCall, DialogToolCallTypedDict
    from .event import Attributes, AttributesTypedDict, Event, EventTypedDict
    from .eventproperties import EventProperties
    from .events_listop import EventsListRequest, EventsListRequestTypedDict
    from .folderdetails import (
        FolderDetails,
        FolderDetailsTypedDict,
        FolderStats,
        FolderStatsTypedDict,
    )
    from .generate_session_recording_urlsop import (
        GenerateSessionRecordingUrlsRequest,
        GenerateSessionRecordingUrlsRequestTypedDict,
    )
    from .get_session_data_by_session_idop import (
        GetSessionDataBySessionIDRequest,
        GetSessionDataBySessionIDRequestTypedDict,
    )
    from .get_session_data_by_sidop import (
        GetSessionDataBySidRequest,
        GetSessionDataBySidRequestTypedDict,
    )
    from .get_session_tool_call_result_by_idop import (
        GetSessionToolCallResultByIDRequest,
        GetSessionToolCallResultByIDRequestTypedDict,
    )
    from .incident_deleteop import IncidentDeleteRequest, IncidentDeleteRequestTypedDict
    from .incident_get_by_idop import (
        IncidentGetByIDRequest,
        IncidentGetByIDRequestTypedDict,
    )
    from .incident_listop import IncidentListRequest, IncidentListRequestTypedDict
    from .incidentcreaterequest import (
        IncidentCreateRequest,
        IncidentCreateRequestTypedDict,
    )
    from .incidentorganizationresponse import (
        IncidentOrganizationResponse,
        IncidentOrganizationResponseTypedDict,
    )
    from .incidentproperties import IncidentProperties
    from .incidentresponse import IncidentResponse, IncidentResponseTypedDict
    from .incidentupdaterequest import (
        IncidentUpdateRequest,
        IncidentUpdateRequestTypedDict,
    )
    from .insight_tool_get_by_idop import (
        InsightToolGetByIDRequest,
        InsightToolGetByIDRequestTypedDict,
    )
    from .insight_tool_listop import (
        InsightToolListRequest,
        InsightToolListRequestTypedDict,
    )
    from .insights_folder_deleteop import (
        InsightsFolderDeleteRequest,
        InsightsFolderDeleteRequestTypedDict,
    )
    from .insights_folder_get_by_idop import (
        InsightsFolderGetByIDRequest,
        InsightsFolderGetByIDRequestTypedDict,
    )
    from .insights_folder_listop import (
        InsightsFolderListRequest,
        InsightsFolderListRequestTypedDict,
    )
    from .insights_folder_updateop import (
        InsightsFolderUpdateRequest,
        InsightsFolderUpdateRequestTypedDict,
    )
    from .insights_folder_upload_fileop import (
        InsightsFolderUploadFileRequest,
        InsightsFolderUploadFileRequestTypedDict,
    )
    from .insights_listop import InsightsListRequest, InsightsListRequestTypedDict
    from .insights_tool_deleteop import (
        InsightsToolDeleteRequest,
        InsightsToolDeleteRequestTypedDict,
    )
    from .insights_tool_updateop import (
        InsightsToolUpdateRequest,
        InsightsToolUpdateRequestTypedDict,
    )
    from .insights_upload_list_filesop import (
        InsightsUploadListFilesRequest,
        InsightsUploadListFilesRequestTypedDict,
    )
    from .insights_upload_move_filesop import (
        InsightsUploadMoveFilesRequest,
        InsightsUploadMoveFilesRequestTypedDict,
    )
    from .insights_workflow_activateop import (
        InsightsWorkflowActivateRequest,
        InsightsWorkflowActivateRequestTypedDict,
    )
    from .insights_workflow_deleteop import (
        InsightsWorkflowDeleteRequest,
        InsightsWorkflowDeleteRequestTypedDict,
    )
    from .insights_workflow_get_by_idop import (
        InsightsWorkflowGetByIDRequest,
        InsightsWorkflowGetByIDRequestTypedDict,
    )
    from .insights_workflow_inactivateop import (
        InsightsWorkflowInactivateRequest,
        InsightsWorkflowInactivateRequestTypedDict,
    )
    from .insights_workflow_listop import (
        InsightsWorkflowListRequest,
        InsightsWorkflowListRequestTypedDict,
    )
    from .insights_workflow_updateop import (
        InsightsWorkflowUpdateRequest,
        InsightsWorkflowUpdateRequestTypedDict,
    )
    from .insightsfolder import InsightsFolder, InsightsFolderTypedDict
    from .insightsfolderfilemove import (
        InsightsFolderFileMove,
        InsightsFolderFileMoveTypedDict,
    )
    from .insightsfolderinput import InsightsFolderInput, InsightsFolderInputTypedDict
    from .insightsfolderproperties import InsightsFolderProperties
    from .insightsoutput import (
        InsightsOutput,
        InsightsOutputTypedDict,
        JSONValue,
        JSONValueTypedDict,
    )
    from .insightsproperties import InsightsProperties
    from .insightsuploadfile import (
        InsightsUploadFile,
        InsightsUploadFileTypedDict,
        Metadata,
        MetadataTypedDict,
    )
    from .insightsuploadfileproperties import InsightsUploadFileProperties
    from .insightsworkflowqueuesession import (
        InsightsWorkflowQueueSession,
        InsightsWorkflowQueueSessionTypedDict,
    )
    from .insighttooldefinition import (
        InsightToolDefinition,
        InsightToolDefinitionTypedDict,
    )
    from .insighttoolinput import InsightToolInput, InsightToolInputTypedDict
    from .insighttooloutput import InsightToolOutput, InsightToolOutputTypedDict
    from .insighttoolproperties import InsightToolProperties
    from .insighttooltestinput import (
        InsightToolTestInput,
        InsightToolTestInputTypedDict,
    )
    from .insightworkflowactivate import (
        InsightWorkflowActivate,
        InsightWorkflowActivateTypedDict,
    )
    from .insightworkflowcondition import (
        AgentList,
        AgentListTypedDict,
        InsightWorkflowCondition,
        InsightWorkflowConditionTypedDict,
        SampleRate,
        SampleRateTypedDict,
    )
    from .insightworkflowestimate import (
        InsightWorkflowEstimate,
        InsightWorkflowEstimateTypedDict,
    )
    from .insightworkflowinput import (
        InsightWorkflowInput,
        InsightWorkflowInputTypedDict,
    )
    from .insightworkflowoutput import (
        InsightWorkflowOutput,
        InsightWorkflowOutputTypedDict,
    )
    from .insightworkflowproperties import InsightWorkflowProperties
    from .inspectlatencyresponse import (
        InspectLatencyResponse,
        InspectLatencyResponseTypedDict,
    )
    from .internaltool import InternalTool, InternalToolTypedDict
    from .language_groups_deleteop import (
        LanguageGroupsDeleteRequest,
        LanguageGroupsDeleteRequestTypedDict,
    )
    from .language_groups_get_by_idop import (
        LanguageGroupsGetByIDRequest,
        LanguageGroupsGetByIDRequestTypedDict,
    )
    from .language_groups_listop import (
        LanguageGroupsListRequest,
        LanguageGroupsListRequestTypedDict,
    )
    from .languagecode import LanguageCode
    from .languageconfig import LanguageConfig, LanguageConfigTypedDict
    from .languagegroupagentinfo import (
        LanguageGroupAgentInfo,
        LanguageGroupAgentInfoTypedDict,
    )
    from .languagegroupcreaterequest import (
        LanguageGroupCreateRequest,
        LanguageGroupCreateRequestTypedDict,
    )
    from .languagegroupproperties import LanguageGroupProperties
    from .languagegroupresponse import (
        LanguageGroupResponse,
        LanguageGroupResponseTypedDict,
    )
    from .languagegroupupdaterequest import (
        LanguageGroupUpdateRequest,
        LanguageGroupUpdateRequestTypedDict,
    )
    from .latencycategory import LatencyCategory
    from .latencyentry import LatencyEntry, LatencyEntryTypedDict
    from .latencyunittype import LatencyUnitType
    from .listresponse_agentresponse_ import (
        ListResponseAgentResponse,
        ListResponseAgentResponseTypedDict,
    )
    from .listresponse_availabletarget_ import (
        ListResponseAvailableTarget,
        ListResponseAvailableTargetTypedDict,
    )
    from .listresponse_channel_ import ListResponseChannel, ListResponseChannelTypedDict
    from .listresponse_channeltargetresponse_ import (
        ListResponseChannelTargetResponse,
        ListResponseChannelTargetResponseTypedDict,
    )
    from .listresponse_communicationbatch_ import (
        ListResponseCommunicationBatch,
        ListResponseCommunicationBatchTypedDict,
    )
    from .listresponse_conversation_ import (
        ListResponseConversation,
        ListResponseConversationTypedDict,
    )
    from .listresponse_custommessageresponse_ import (
        ListResponseCustomMessageResponse,
        ListResponseCustomMessageResponseTypedDict,
    )
    from .listresponse_dashboardresponse_ import (
        ListResponseDashboardResponse,
        ListResponseDashboardResponseTypedDict,
    )
    from .listresponse_datasourcemetadataresponse_ import (
        ListResponseDataSourceMetadataResponse,
        ListResponseDataSourceMetadataResponseTypedDict,
    )
    from .listresponse_event_ import ListResponseEvent, ListResponseEventTypedDict
    from .listresponse_incidentresponse_ import (
        ListResponseIncidentResponse,
        ListResponseIncidentResponseTypedDict,
    )
    from .listresponse_insightsfolder_ import (
        ListResponseInsightsFolder,
        ListResponseInsightsFolderTypedDict,
    )
    from .listresponse_insightsoutput_ import (
        ListResponseInsightsOutput,
        ListResponseInsightsOutputTypedDict,
    )
    from .listresponse_insightsuploadfile_ import (
        ListResponseInsightsUploadFile,
        ListResponseInsightsUploadFileTypedDict,
    )
    from .listresponse_insighttooloutput_ import (
        ListResponseInsightToolOutput,
        ListResponseInsightToolOutputTypedDict,
    )
    from .listresponse_insightworkflowoutput_ import (
        ListResponseInsightWorkflowOutput,
        ListResponseInsightWorkflowOutputTypedDict,
    )
    from .listresponse_languagegroupresponse_ import (
        ListResponseLanguageGroupResponse,
        ListResponseLanguageGroupResponseTypedDict,
    )
    from .listresponse_outboundcampaign_ import (
        ListResponseOutboundCampaign,
        ListResponseOutboundCampaignTypedDict,
    )
    from .listresponse_promptresponse_ import (
        ListResponsePromptResponse,
        ListResponsePromptResponseTypedDict,
    )
    from .listresponse_roleresponse_ import (
        ListResponseRoleResponse,
        ListResponseRoleResponseTypedDict,
    )
    from .listresponse_serviceresponse_ import (
        ListResponseServiceResponse,
        ListResponseServiceResponseTypedDict,
    )
    from .listresponse_session_ import ListResponseSession, ListResponseSessionTypedDict
    from .listresponse_sessionlabel_ import (
        ListResponseSessionLabel,
        ListResponseSessionLabelTypedDict,
    )
    from .listresponse_toolresponse_ import (
        ListResponseToolResponse,
        ListResponseToolResponseTypedDict,
    )
    from .listresponse_userresponse_ import (
        ListResponseUserResponse,
        ListResponseUserResponseTypedDict,
    )
    from .logintype import LoginType
    from .orderbydirection import OrderByDirection
    from .organizationchannelconfig import (
        OrganizationChannelConfig,
        OrganizationChannelConfigTypedDict,
    )
    from .organizationchannelcreaterequest import (
        OrganizationChannelCreateRequest,
        OrganizationChannelCreateRequestTypedDict,
    )
    from .organizationchannelupdaterequest import (
        OrganizationChannelUpdateRequest,
        OrganizationChannelUpdateRequestTypedDict,
    )
    from .organizationresponse import (
        OrganizationResponse,
        OrganizationResponseTypedDict,
    )
    from .outbound_batch_addop import (
        OutboundBatchAddRequest,
        OutboundBatchAddRequestTypedDict,
    )
    from .outbound_batch_deleteop import (
        OutboundBatchDeleteRequest,
        OutboundBatchDeleteRequestTypedDict,
    )
    from .outbound_batch_get_by_idop import (
        OutboundBatchGetByIDRequest,
        OutboundBatchGetByIDRequestTypedDict,
    )
    from .outbound_batch_listop import (
        OutboundBatchListRequest,
        OutboundBatchListRequestTypedDict,
    )
    from .outbound_batch_removeop import (
        OutboundBatchRemoveRequest,
        OutboundBatchRemoveRequestTypedDict,
    )
    from .outbound_batch_resultsop import (
        OutboundBatchResultsRequest,
        OutboundBatchResultsRequestTypedDict,
    )
    from .outbound_batch_updateop import (
        OutboundBatchUpdateRequest,
        OutboundBatchUpdateRequestTypedDict,
    )
    from .outbound_batch_uploadop import (
        OutboundBatchUploadRequest,
        OutboundBatchUploadRequestTypedDict,
    )
    from .outbound_campaign_deleteop import (
        OutboundCampaignDeleteRequest,
        OutboundCampaignDeleteRequestTypedDict,
    )
    from .outbound_campaign_get_by_idop import (
        OutboundCampaignGetByIDRequest,
        OutboundCampaignGetByIDRequestTypedDict,
    )
    from .outbound_campaign_listop import (
        OutboundCampaignListRequest,
        OutboundCampaignListRequestTypedDict,
    )
    from .outbound_campaign_updateop import (
        OutboundCampaignUpdateRequest,
        OutboundCampaignUpdateRequestTypedDict,
    )
    from .outboundcampaign import OutboundCampaign, OutboundCampaignTypedDict
    from .outboundcampaigninput import (
        OutboundCampaignInput,
        OutboundCampaignInputTypedDict,
    )
    from .permissiongroupresponse import (
        PermissionGroupResponse,
        PermissionGroupResponseTypedDict,
    )
    from .permissionresponse import PermissionResponse, PermissionResponseTypedDict
    from .post_get_dashboardop import (
        PostGetDashboardRequest,
        PostGetDashboardRequestTypedDict,
    )
    from .post_list_dashboardop import (
        PostListDashboardRequest,
        PostListDashboardRequestTypedDict,
    )
    from .promptcreaterequest import PromptCreateRequest, PromptCreateRequestTypedDict
    from .prompthistory import PromptHistory, PromptHistoryTypedDict
    from .prompthistorylinkedtool import (
        PromptHistoryLinkedTool,
        PromptHistoryLinkedToolTypedDict,
    )
    from .promptllmconfig import PromptLlmConfig, PromptLlmConfigTypedDict
    from .promptllmprovider import PromptLlmProvider
    from .promptproperties import PromptProperties
    from .promptresponse import PromptResponse, PromptResponseTypedDict
    from .prompts_deleteop import PromptsDeleteRequest, PromptsDeleteRequestTypedDict
    from .prompts_get_by_idop import (
        PromptsGetByIDRequest,
        PromptsGetByIDRequestTypedDict,
    )
    from .prompts_historyop import PromptsHistoryRequest, PromptsHistoryRequestTypedDict
    from .prompts_listop import PromptsListRequest, PromptsListRequestTypedDict
    from .promptupdaterequest import PromptUpdateRequest, PromptUpdateRequestTypedDict
    from .requeststatus import RequestStatus
    from .rolecreaterequest import RoleCreateRequest, RoleCreateRequestTypedDict
    from .roleproperties import RoleProperties
    from .roleresponse import RoleResponse, RoleResponseTypedDict
    from .roles_deleteop import RolesDeleteRequest, RolesDeleteRequestTypedDict
    from .roles_get_by_idop import RolesGetByIDRequest, RolesGetByIDRequestTypedDict
    from .roles_listop import RolesListRequest, RolesListRequestTypedDict
    from .roleupdaterequest import RoleUpdateRequest, RoleUpdateRequestTypedDict
    from .security import Security, SecurityTypedDict
    from .service_deleteop import ServiceDeleteRequest, ServiceDeleteRequestTypedDict
    from .service_listop import ServiceListRequest, ServiceListRequestTypedDict
    from .servicecreaterequest import (
        ServiceCreateRequest,
        ServiceCreateRequestTypedDict,
    )
    from .serviceproperties import ServiceProperties
    from .serviceresponse import ServiceResponse, ServiceResponseTypedDict
    from .services_get_by_idop import (
        ServicesGetByIDRequest,
        ServicesGetByIDRequestTypedDict,
    )
    from .serviceupdaterequest import (
        ServiceUpdateRequest,
        ServiceUpdateRequestTypedDict,
    )
    from .session import Session, SessionTypedDict
    from .session_full_summary_get_by_idop import (
        SessionFullSummaryGetByIDRequest,
        SessionFullSummaryGetByIDRequestTypedDict,
    )
    from .session_get_by_idop import (
        SessionGetByIDRequest,
        SessionGetByIDRequestTypedDict,
    )
    from .session_label_get_by_idop import (
        SessionLabelGetByIDRequest,
        SessionLabelGetByIDRequestTypedDict,
    )
    from .session_labels_listop import (
        SessionLabelsListRequest,
        SessionLabelsListRequestTypedDict,
    )
    from .session_latency_get_by_idop import (
        SessionLatencyGetByIDRequest,
        SessionLatencyGetByIDRequestTypedDict,
    )
    from .session_recording_streamop import (
        SessionRecordingStreamRequest,
        SessionRecordingStreamRequestTypedDict,
    )
    from .session_transcript_get_by_idop import (
        SessionTranscriptGetByIDRequest,
        SessionTranscriptGetByIDRequestTypedDict,
    )
    from .sessionaction import SessionAction, SessionActionTypedDict
    from .sessiondata import SessionData, SessionDataTypedDict
    from .sessionlabel import SessionLabel, SessionLabelTypedDict
    from .sessionlabelcreate import SessionLabelCreate, SessionLabelCreateTypedDict
    from .sessionlabelproperties import SessionLabelProperties
    from .sessionmessage import SessionMessage, SessionMessageTypedDict
    from .sessionproperties import SessionProperties
    from .sessionrecordingresponse import (
        SessionRecordingResponse,
        SessionRecordingResponseTypedDict,
    )
    from .sessions_listop import SessionsListRequest, SessionsListRequestTypedDict
    from .sessionsummaryresponse import (
        SessionSummaryResponse,
        SessionSummaryResponseTypedDict,
    )
    from .sessiontext import SessionText, SessionTextTypedDict
    from .sessiontranscriptionresponse import (
        SessionTranscriptionResponse,
        SessionTranscriptionResponseTypedDict,
    )
    from .statictoolparameter import StaticToolParameter, StaticToolParameterTypedDict
    from .statictoolparametertype import StaticToolParameterType
    from .summaryentry import SummaryEntry, SummaryEntryTypedDict
    from .supportedllm import SupportedLlm, SupportedLlmTypedDict
    from .takeoutrequeststatus import TakeoutRequestStatus
    from .takeouts_get_by_job_idop import (
        TakeoutsGetByJobIDRequest,
        TakeoutsGetByJobIDRequestTypedDict,
    )
    from .takeouts_get_fileop import (
        TakeoutsGetFileRequest,
        TakeoutsGetFileRequestTypedDict,
    )
    from .takeoutstatusresponse import (
        TakeoutStatusResponse,
        TakeoutStatusResponseTypedDict,
    )
    from .targetmodes import TargetModes
    from .telephonyconfigurations import (
        TelephonyConfigurations,
        TelephonyConfigurationsTypedDict,
    )
    from .testmessage import TestMessage, TestMessageTypedDict
    from .testmessageresponse import TestMessageResponse, TestMessageResponseTypedDict
    from .tool_deleteop import ToolDeleteRequest, ToolDeleteRequestTypedDict
    from .tool_get_by_nameop import ToolGetByNameRequest, ToolGetByNameRequestTypedDict
    from .tool_listop import ToolListRequest, ToolListRequestTypedDict
    from .toolagentinfo import ToolAgentInfo, ToolAgentInfoTypedDict
    from .toolargumentlocation import ToolArgumentLocation
    from .toolauthtype import ToolAuthType
    from .toolcreaterequest import ToolCreateRequest, ToolCreateRequestTypedDict
    from .tooldefinition import (
        Defaults,
        DefaultsTypedDict,
        ToolDefinition,
        ToolDefinitionTypedDict,
        Type,
    )
    from .tooldetailresponse import ToolDetailResponse, ToolDetailResponseTypedDict
    from .toolfunction import ToolFunction, ToolFunctionTypedDict
    from .toolhttpendpoint import ToolHTTPEndpoint, ToolHTTPEndpointTypedDict
    from .toolhttpmethod import ToolHTTPMethod
    from .tooloptions import ToolOptions, ToolOptionsTypedDict
    from .toolparameterdefault import (
        ToolParameterDefault,
        ToolParameterDefaultTypedDict,
    )
    from .toolparametertransform import (
        Action,
        ToolParameterTransform,
        ToolParameterTransformTypedDict,
    )
    from .toolparametertransformcondition import (
        ToolParameterTransformCondition,
        ToolParameterTransformConditionTypedDict,
    )
    from .toolpromptinfo import ToolPromptInfo, ToolPromptInfoTypedDict
    from .toolproperties import ToolProperties
    from .toolresponse import ToolResponse, ToolResponseTypedDict
    from .toolresultdata import ToolResultData, ToolResultDataTypedDict
    from .toolupdaterequest import ToolUpdateRequest, ToolUpdateRequestTypedDict
    from .ttsprovider import TtsProvider
    from .twiliochannelconfigcreate import (
        TwilioChannelConfigCreate,
        TwilioChannelConfigCreateTypedDict,
    )
    from .twiliochannelconfigupdate import (
        TwilioChannelConfigUpdate,
        TwilioChannelConfigUpdateTypedDict,
    )
    from .twiliochannelcreaterequest import (
        TwilioChannelCreateRequest,
        TwilioChannelCreateRequestTypedDict,
    )
    from .twiliochannelupdaterequest import (
        TwilioChannelUpdateRequest,
        TwilioChannelUpdateRequestTypedDict,
    )
    from .twiliolistnumbersresponse import (
        TwilioListNumbersResponse,
        TwilioListNumbersResponseTypedDict,
    )
    from .twilionumberaddrequest import (
        TwilioNumberAddRequest,
        TwilioNumberAddRequestTypedDict,
    )
    from .twilionumberaddresponse import (
        TwilioNumberAddResponse,
        TwilioNumberAddResponseTypedDict,
    )
    from .twilionumberupdaterequest import (
        TwilioNumberUpdateRequest,
        TwilioNumberUpdateRequestTypedDict,
    )
    from .twilionumberupdateresponse import (
        TwilioNumberUpdateResponse,
        TwilioNumberUpdateResponseTypedDict,
    )
    from .twiliophonenumber import TwilioPhoneNumber, TwilioPhoneNumberTypedDict
    from .useractivitystatus import UserActivityStatus
    from .usercreaterequest import UserCreateRequest, UserCreateRequestTypedDict
    from .userdeleterequest import UserDeleteRequest, UserDeleteRequestTypedDict
    from .userproperties import UserProperties
    from .userresponse import UserResponse, UserResponseTypedDict
    from .users_get_by_emailop import (
        UsersGetByEmailRequest,
        UsersGetByEmailRequestTypedDict,
    )
    from .users_listop import UsersListRequest, UsersListRequestTypedDict
    from .users_send_emailop import (
        UsersSendEmailRequest,
        UsersSendEmailRequestTypedDict,
    )
    from .userupdaterequest import UserUpdateRequest, UserUpdateRequestTypedDict
    from .validationerror import (
        Loc,
        LocTypedDict,
        ValidationError,
        ValidationErrorTypedDict,
    )
    from .voicesamplecreaterequest import (
        VoiceSampleCreateRequest,
        VoiceSampleCreateRequestTypedDict,
    )  # Pydantic models with forward references
AgentResponse.model_rebuild()
ChannelTargetResponse.model_rebuild()


__all__ = [
    "Action",
    "AgentCreate",
    "AgentCreateTypedDict",
    "AgentDeleteRequest",
    "AgentDeleteRequestTypedDict",
    "AgentGetByIDRequest",
    "AgentGetByIDRequestTypedDict",
    "AgentLanguage",
    "AgentLanguageTypedDict",
    "AgentList",
    "AgentListRequest",
    "AgentListRequestTypedDict",
    "AgentListTypedDict",
    "AgentProperties",
    "AgentResponse",
    "AgentResponseTypedDict",
    "AgentSttProvider",
    "AgentToolDefaults",
    "AgentToolDefaultsTypedDict",
    "AgentToolFieldDefault",
    "AgentToolFieldDefaultTypedDict",
    "AgentUpdate",
    "AgentUpdateTypedDict",
    "AgentVoice",
    "AgentVoiceDisplayName",
    "AgentVoiceGender",
    "AgentVoiceModel",
    "AgentVoiceTypedDict",
    "AgentVoiceVarName",
    "AgentWaitSound",
    "Attributes",
    "AttributesTypedDict",
    "AvailableTarget",
    "AvailableTargetProperties",
    "AvailableTargetTypedDict",
    "AvailableTargetsRequest",
    "AvailableTargetsRequestTypedDict",
    "BatchDetails",
    "BatchDetailsTypedDict",
    "BatchProperties",
    "BatchStatus",
    "BodyInsightsFolderUploadFile",
    "BodyInsightsFolderUploadFileFile",
    "BodyInsightsFolderUploadFileFileTypedDict",
    "BodyInsightsFolderUploadFileTypedDict",
    "BodyOrganizationsCreate",
    "BodyOrganizationsCreateLogo",
    "BodyOrganizationsCreateLogoTypedDict",
    "BodyOrganizationsCreateTypedDict",
    "BodyOrganizationsDelete",
    "BodyOrganizationsDeleteTypedDict",
    "BodyOrganizationsUpdate",
    "BodyOrganizationsUpdateLogo",
    "BodyOrganizationsUpdateLogoTypedDict",
    "BodyOrganizationsUpdateTypedDict",
    "BodyOutboundBatchDelete",
    "BodyOutboundBatchDeleteTypedDict",
    "BodyOutboundBatchUpload",
    "BodyOutboundBatchUploadFile",
    "BodyOutboundBatchUploadFileTypedDict",
    "BodyOutboundBatchUploadTypedDict",
    "CampaignProperties",
    "Channel",
    "ChannelConfigView",
    "ChannelConfigViewTypedDict",
    "ChannelProperties",
    "ChannelServices",
    "ChannelTargetCreateRequest",
    "ChannelTargetCreateRequestTypedDict",
    "ChannelTargetProperties",
    "ChannelTargetResponse",
    "ChannelTargetResponseTypedDict",
    "ChannelTargetUpdateRequest",
    "ChannelTargetUpdateRequestTypedDict",
    "ChannelTargetsCreateRequest",
    "ChannelTargetsCreateRequestTypedDict",
    "ChannelTargetsDeleteRequest",
    "ChannelTargetsDeleteRequestTypedDict",
    "ChannelTargetsGetByIDRequest",
    "ChannelTargetsGetByIDRequestTypedDict",
    "ChannelTargetsListRequest",
    "ChannelTargetsListRequestTypedDict",
    "ChannelTargetsUpdateRequest",
    "ChannelTargetsUpdateRequestTypedDict",
    "ChannelTypedDict",
    "ChannelsListRequest",
    "ChannelsListRequestTypedDict",
    "ChannelsTwilioGetByIDRequest",
    "ChannelsTwilioGetByIDRequestTypedDict",
    "ChannelsTwilioNumbersAddRequest",
    "ChannelsTwilioNumbersAddRequestTypedDict",
    "ChannelsTwilioNumbersListRequest",
    "ChannelsTwilioNumbersListRequestTypedDict",
    "ChannelsTwilioNumbersUpdateRequest",
    "ChannelsTwilioNumbersUpdateRequestTypedDict",
    "CommunicationBatch",
    "CommunicationBatchInput",
    "CommunicationBatchInputTypedDict",
    "CommunicationBatchTypedDict",
    "CommunicationBatchUpdate",
    "CommunicationBatchUpdateTypedDict",
    "CommunicationRequest",
    "CommunicationRequestResult",
    "CommunicationRequestResultTypedDict",
    "CommunicationRequestTypedDict",
    "Conversation",
    "ConversationProperties",
    "ConversationTypedDict",
    "ConversationsListRequest",
    "ConversationsListRequestTypedDict",
    "CreateTakeoutResponse",
    "CreateTakeoutResponseTypedDict",
    "CustomMessageCreateRequest",
    "CustomMessageCreateRequestTypedDict",
    "CustomMessageGetByIDRequest",
    "CustomMessageGetByIDRequestTypedDict",
    "CustomMessageProperties",
    "CustomMessageResponse",
    "CustomMessageResponseTypedDict",
    "CustomMessageRule",
    "CustomMessageRuleTypedDict",
    "CustomMessageUpdateRequest",
    "CustomMessageUpdateRequestTypedDict",
    "CustomMessagesDeleteRequest",
    "CustomMessagesDeleteRequestTypedDict",
    "CustomMessagesListRequest",
    "CustomMessagesListRequestTypedDict",
    "Dashboard",
    "DashboardProperties",
    "DashboardResponse",
    "DashboardResponseTypedDict",
    "DashboardTokenResponse",
    "DashboardTokenResponseTypedDict",
    "DashboardTypedDict",
    "DataSourceCreateRequest",
    "DataSourceCreateRequestTypedDict",
    "DataSourceDetailResponse",
    "DataSourceDetailResponseTypedDict",
    "DataSourceMetadataResponse",
    "DataSourceMetadataResponseTypedDict",
    "DataSourceProperties",
    "DataSourceUpdateRequest",
    "DataSourceUpdateRequestTypedDict",
    "DataSourcesDeleteRequest",
    "DataSourcesDeleteRequestTypedDict",
    "DataSourcesGetByIDRequest",
    "DataSourcesGetByIDRequestTypedDict",
    "DataSourcesListRequest",
    "DataSourcesListRequestTypedDict",
    "DayOfWeek",
    "DaysOfWeek",
    "Defaults",
    "DefaultsTypedDict",
    "DialogMessage",
    "DialogMessageTypedDict",
    "DialogRole",
    "DialogToolCall",
    "DialogToolCallTypedDict",
    "Event",
    "EventProperties",
    "EventTypedDict",
    "EventsListRequest",
    "EventsListRequestTypedDict",
    "FolderDetails",
    "FolderDetailsTypedDict",
    "FolderStats",
    "FolderStatsTypedDict",
    "GenerateSessionRecordingUrlsRequest",
    "GenerateSessionRecordingUrlsRequestTypedDict",
    "GetSessionDataBySessionIDRequest",
    "GetSessionDataBySessionIDRequestTypedDict",
    "GetSessionDataBySidRequest",
    "GetSessionDataBySidRequestTypedDict",
    "GetSessionToolCallResultByIDRequest",
    "GetSessionToolCallResultByIDRequestTypedDict",
    "IncidentCreateRequest",
    "IncidentCreateRequestTypedDict",
    "IncidentDeleteRequest",
    "IncidentDeleteRequestTypedDict",
    "IncidentGetByIDRequest",
    "IncidentGetByIDRequestTypedDict",
    "IncidentListRequest",
    "IncidentListRequestTypedDict",
    "IncidentOrganizationResponse",
    "IncidentOrganizationResponseTypedDict",
    "IncidentProperties",
    "IncidentResponse",
    "IncidentResponseTypedDict",
    "IncidentUpdateRequest",
    "IncidentUpdateRequestTypedDict",
    "InsightToolDefinition",
    "InsightToolDefinitionTypedDict",
    "InsightToolGetByIDRequest",
    "InsightToolGetByIDRequestTypedDict",
    "InsightToolInput",
    "InsightToolInputTypedDict",
    "InsightToolListRequest",
    "InsightToolListRequestTypedDict",
    "InsightToolOutput",
    "InsightToolOutputTypedDict",
    "InsightToolProperties",
    "InsightToolTestInput",
    "InsightToolTestInputTypedDict",
    "InsightWorkflowActivate",
    "InsightWorkflowActivateTypedDict",
    "InsightWorkflowCondition",
    "InsightWorkflowConditionTypedDict",
    "InsightWorkflowEstimate",
    "InsightWorkflowEstimateTypedDict",
    "InsightWorkflowInput",
    "InsightWorkflowInputTypedDict",
    "InsightWorkflowOutput",
    "InsightWorkflowOutputTypedDict",
    "InsightWorkflowProperties",
    "Insights",
    "InsightsFolder",
    "InsightsFolderDeleteRequest",
    "InsightsFolderDeleteRequestTypedDict",
    "InsightsFolderFileMove",
    "InsightsFolderFileMoveTypedDict",
    "InsightsFolderGetByIDRequest",
    "InsightsFolderGetByIDRequestTypedDict",
    "InsightsFolderInput",
    "InsightsFolderInputTypedDict",
    "InsightsFolderListRequest",
    "InsightsFolderListRequestTypedDict",
    "InsightsFolderProperties",
    "InsightsFolderTypedDict",
    "InsightsFolderUpdateRequest",
    "InsightsFolderUpdateRequestTypedDict",
    "InsightsFolderUploadFileRequest",
    "InsightsFolderUploadFileRequestTypedDict",
    "InsightsListRequest",
    "InsightsListRequestTypedDict",
    "InsightsOutput",
    "InsightsOutputTypedDict",
    "InsightsProperties",
    "InsightsToolDeleteRequest",
    "InsightsToolDeleteRequestTypedDict",
    "InsightsToolUpdateRequest",
    "InsightsToolUpdateRequestTypedDict",
    "InsightsTypedDict",
    "InsightsUploadFile",
    "InsightsUploadFileProperties",
    "InsightsUploadFileTypedDict",
    "InsightsUploadListFilesRequest",
    "InsightsUploadListFilesRequestTypedDict",
    "InsightsUploadMoveFilesRequest",
    "InsightsUploadMoveFilesRequestTypedDict",
    "InsightsWorkflowActivateRequest",
    "InsightsWorkflowActivateRequestTypedDict",
    "InsightsWorkflowDeleteRequest",
    "InsightsWorkflowDeleteRequestTypedDict",
    "InsightsWorkflowGetByIDRequest",
    "InsightsWorkflowGetByIDRequestTypedDict",
    "InsightsWorkflowInactivateRequest",
    "InsightsWorkflowInactivateRequestTypedDict",
    "InsightsWorkflowListRequest",
    "InsightsWorkflowListRequestTypedDict",
    "InsightsWorkflowQueueSession",
    "InsightsWorkflowQueueSessionTypedDict",
    "InsightsWorkflowUpdateRequest",
    "InsightsWorkflowUpdateRequestTypedDict",
    "InspectLatencyResponse",
    "InspectLatencyResponseTypedDict",
    "InternalTool",
    "InternalToolTypedDict",
    "JSONValue",
    "JSONValueTypedDict",
    "LanguageCode",
    "LanguageConfig",
    "LanguageConfigTypedDict",
    "LanguageGroupAgentInfo",
    "LanguageGroupAgentInfoTypedDict",
    "LanguageGroupCreateRequest",
    "LanguageGroupCreateRequestTypedDict",
    "LanguageGroupProperties",
    "LanguageGroupResponse",
    "LanguageGroupResponseTypedDict",
    "LanguageGroupUpdateRequest",
    "LanguageGroupUpdateRequestTypedDict",
    "LanguageGroupsDeleteRequest",
    "LanguageGroupsDeleteRequestTypedDict",
    "LanguageGroupsGetByIDRequest",
    "LanguageGroupsGetByIDRequestTypedDict",
    "LanguageGroupsListRequest",
    "LanguageGroupsListRequestTypedDict",
    "LatencyCategory",
    "LatencyEntry",
    "LatencyEntryTypedDict",
    "LatencyUnitType",
    "ListResponseAgentResponse",
    "ListResponseAgentResponseTypedDict",
    "ListResponseAvailableTarget",
    "ListResponseAvailableTargetTypedDict",
    "ListResponseChannel",
    "ListResponseChannelTargetResponse",
    "ListResponseChannelTargetResponseTypedDict",
    "ListResponseChannelTypedDict",
    "ListResponseCommunicationBatch",
    "ListResponseCommunicationBatchTypedDict",
    "ListResponseConversation",
    "ListResponseConversationTypedDict",
    "ListResponseCustomMessageResponse",
    "ListResponseCustomMessageResponseTypedDict",
    "ListResponseDashboardResponse",
    "ListResponseDashboardResponseTypedDict",
    "ListResponseDataSourceMetadataResponse",
    "ListResponseDataSourceMetadataResponseTypedDict",
    "ListResponseEvent",
    "ListResponseEventTypedDict",
    "ListResponseIncidentResponse",
    "ListResponseIncidentResponseTypedDict",
    "ListResponseInsightToolOutput",
    "ListResponseInsightToolOutputTypedDict",
    "ListResponseInsightWorkflowOutput",
    "ListResponseInsightWorkflowOutputTypedDict",
    "ListResponseInsightsFolder",
    "ListResponseInsightsFolderTypedDict",
    "ListResponseInsightsOutput",
    "ListResponseInsightsOutputTypedDict",
    "ListResponseInsightsUploadFile",
    "ListResponseInsightsUploadFileTypedDict",
    "ListResponseLanguageGroupResponse",
    "ListResponseLanguageGroupResponseTypedDict",
    "ListResponseOutboundCampaign",
    "ListResponseOutboundCampaignTypedDict",
    "ListResponsePromptResponse",
    "ListResponsePromptResponseTypedDict",
    "ListResponseRoleResponse",
    "ListResponseRoleResponseTypedDict",
    "ListResponseServiceResponse",
    "ListResponseServiceResponseTypedDict",
    "ListResponseSession",
    "ListResponseSessionLabel",
    "ListResponseSessionLabelTypedDict",
    "ListResponseSessionTypedDict",
    "ListResponseToolResponse",
    "ListResponseToolResponseTypedDict",
    "ListResponseUserResponse",
    "ListResponseUserResponseTypedDict",
    "Loc",
    "LocTypedDict",
    "LoginType",
    "Metadata",
    "MetadataTypedDict",
    "OrderByDirection",
    "OrganizationChannelConfig",
    "OrganizationChannelConfigTypedDict",
    "OrganizationChannelCreateRequest",
    "OrganizationChannelCreateRequestTypedDict",
    "OrganizationChannelUpdateRequest",
    "OrganizationChannelUpdateRequestTypedDict",
    "OrganizationResponse",
    "OrganizationResponseTypedDict",
    "OutboundBatchAddRequest",
    "OutboundBatchAddRequestTypedDict",
    "OutboundBatchDeleteRequest",
    "OutboundBatchDeleteRequestTypedDict",
    "OutboundBatchGetByIDRequest",
    "OutboundBatchGetByIDRequestTypedDict",
    "OutboundBatchListRequest",
    "OutboundBatchListRequestTypedDict",
    "OutboundBatchRemoveRequest",
    "OutboundBatchRemoveRequestTypedDict",
    "OutboundBatchResultsRequest",
    "OutboundBatchResultsRequestTypedDict",
    "OutboundBatchUpdateRequest",
    "OutboundBatchUpdateRequestTypedDict",
    "OutboundBatchUploadRequest",
    "OutboundBatchUploadRequestTypedDict",
    "OutboundCampaign",
    "OutboundCampaignDeleteRequest",
    "OutboundCampaignDeleteRequestTypedDict",
    "OutboundCampaignGetByIDRequest",
    "OutboundCampaignGetByIDRequestTypedDict",
    "OutboundCampaignInput",
    "OutboundCampaignInputTypedDict",
    "OutboundCampaignListRequest",
    "OutboundCampaignListRequestTypedDict",
    "OutboundCampaignTypedDict",
    "OutboundCampaignUpdateRequest",
    "OutboundCampaignUpdateRequestTypedDict",
    "PermissionGroupResponse",
    "PermissionGroupResponseTypedDict",
    "PermissionResponse",
    "PermissionResponseTypedDict",
    "PostGetDashboardRequest",
    "PostGetDashboardRequestTypedDict",
    "PostListDashboardRequest",
    "PostListDashboardRequestTypedDict",
    "PromptCreateRequest",
    "PromptCreateRequestTypedDict",
    "PromptHistory",
    "PromptHistoryLinkedTool",
    "PromptHistoryLinkedToolTypedDict",
    "PromptHistoryTypedDict",
    "PromptLlmConfig",
    "PromptLlmConfigTypedDict",
    "PromptLlmProvider",
    "PromptProperties",
    "PromptResponse",
    "PromptResponseTypedDict",
    "PromptUpdateRequest",
    "PromptUpdateRequestTypedDict",
    "PromptsDeleteRequest",
    "PromptsDeleteRequestTypedDict",
    "PromptsGetByIDRequest",
    "PromptsGetByIDRequestTypedDict",
    "PromptsHistoryRequest",
    "PromptsHistoryRequestTypedDict",
    "PromptsListRequest",
    "PromptsListRequestTypedDict",
    "RequestStatus",
    "RoleCreateRequest",
    "RoleCreateRequestTypedDict",
    "RoleProperties",
    "RoleResponse",
    "RoleResponseTypedDict",
    "RoleUpdateRequest",
    "RoleUpdateRequestTypedDict",
    "RolesDeleteRequest",
    "RolesDeleteRequestTypedDict",
    "RolesGetByIDRequest",
    "RolesGetByIDRequestTypedDict",
    "RolesListRequest",
    "RolesListRequestTypedDict",
    "SampleRate",
    "SampleRateTypedDict",
    "Security",
    "SecurityTypedDict",
    "ServiceCreateRequest",
    "ServiceCreateRequestTypedDict",
    "ServiceDeleteRequest",
    "ServiceDeleteRequestTypedDict",
    "ServiceListRequest",
    "ServiceListRequestTypedDict",
    "ServiceProperties",
    "ServiceResponse",
    "ServiceResponseTypedDict",
    "ServiceUpdateRequest",
    "ServiceUpdateRequestTypedDict",
    "ServicesGetByIDRequest",
    "ServicesGetByIDRequestTypedDict",
    "Session",
    "SessionAction",
    "SessionActionTypedDict",
    "SessionData",
    "SessionDataTypedDict",
    "SessionFullSummaryGetByIDRequest",
    "SessionFullSummaryGetByIDRequestTypedDict",
    "SessionGetByIDRequest",
    "SessionGetByIDRequestTypedDict",
    "SessionLabel",
    "SessionLabelCreate",
    "SessionLabelCreateTypedDict",
    "SessionLabelGetByIDRequest",
    "SessionLabelGetByIDRequestTypedDict",
    "SessionLabelProperties",
    "SessionLabelTypedDict",
    "SessionLabelsListRequest",
    "SessionLabelsListRequestTypedDict",
    "SessionLatencyGetByIDRequest",
    "SessionLatencyGetByIDRequestTypedDict",
    "SessionMessage",
    "SessionMessageTypedDict",
    "SessionProperties",
    "SessionRecordingResponse",
    "SessionRecordingResponseTypedDict",
    "SessionRecordingStreamRequest",
    "SessionRecordingStreamRequestTypedDict",
    "SessionSummaryResponse",
    "SessionSummaryResponseTypedDict",
    "SessionText",
    "SessionTextTypedDict",
    "SessionTranscriptGetByIDRequest",
    "SessionTranscriptGetByIDRequestTypedDict",
    "SessionTranscriptionResponse",
    "SessionTranscriptionResponseTypedDict",
    "SessionTypedDict",
    "SessionsListRequest",
    "SessionsListRequestTypedDict",
    "StaticToolParameter",
    "StaticToolParameterType",
    "StaticToolParameterTypedDict",
    "SummaryEntry",
    "SummaryEntryTypedDict",
    "SupportedLlm",
    "SupportedLlmTypedDict",
    "TakeoutRequestStatus",
    "TakeoutStatusResponse",
    "TakeoutStatusResponseTypedDict",
    "TakeoutsGetByJobIDRequest",
    "TakeoutsGetByJobIDRequestTypedDict",
    "TakeoutsGetFileRequest",
    "TakeoutsGetFileRequestTypedDict",
    "TargetModes",
    "TelephonyConfigurations",
    "TelephonyConfigurationsTypedDict",
    "TestMessage",
    "TestMessageResponse",
    "TestMessageResponseTypedDict",
    "TestMessageTypedDict",
    "ToolAgentInfo",
    "ToolAgentInfoTypedDict",
    "ToolArgumentLocation",
    "ToolAuthType",
    "ToolCreateRequest",
    "ToolCreateRequestTypedDict",
    "ToolDefinition",
    "ToolDefinitionTypedDict",
    "ToolDeleteRequest",
    "ToolDeleteRequestTypedDict",
    "ToolDetailResponse",
    "ToolDetailResponseTypedDict",
    "ToolFunction",
    "ToolFunctionTypedDict",
    "ToolGetByNameRequest",
    "ToolGetByNameRequestTypedDict",
    "ToolHTTPEndpoint",
    "ToolHTTPEndpointTypedDict",
    "ToolHTTPMethod",
    "ToolListRequest",
    "ToolListRequestTypedDict",
    "ToolOptions",
    "ToolOptionsTypedDict",
    "ToolParameterDefault",
    "ToolParameterDefaultTypedDict",
    "ToolParameterTransform",
    "ToolParameterTransformCondition",
    "ToolParameterTransformConditionTypedDict",
    "ToolParameterTransformTypedDict",
    "ToolPromptInfo",
    "ToolPromptInfoTypedDict",
    "ToolProperties",
    "ToolResponse",
    "ToolResponseTypedDict",
    "ToolResultData",
    "ToolResultDataTypedDict",
    "ToolUpdateRequest",
    "ToolUpdateRequestTypedDict",
    "TtsProvider",
    "TwilioChannelConfigCreate",
    "TwilioChannelConfigCreateTypedDict",
    "TwilioChannelConfigUpdate",
    "TwilioChannelConfigUpdateTypedDict",
    "TwilioChannelCreateRequest",
    "TwilioChannelCreateRequestTypedDict",
    "TwilioChannelUpdateRequest",
    "TwilioChannelUpdateRequestTypedDict",
    "TwilioListNumbersResponse",
    "TwilioListNumbersResponseTypedDict",
    "TwilioNumberAddRequest",
    "TwilioNumberAddRequestTypedDict",
    "TwilioNumberAddResponse",
    "TwilioNumberAddResponseTypedDict",
    "TwilioNumberUpdateRequest",
    "TwilioNumberUpdateRequestTypedDict",
    "TwilioNumberUpdateResponse",
    "TwilioNumberUpdateResponseTypedDict",
    "TwilioPhoneNumber",
    "TwilioPhoneNumberTypedDict",
    "Type",
    "UserActivityStatus",
    "UserCreateRequest",
    "UserCreateRequestTypedDict",
    "UserDeleteRequest",
    "UserDeleteRequestTypedDict",
    "UserProperties",
    "UserResponse",
    "UserResponseTypedDict",
    "UserUpdateRequest",
    "UserUpdateRequestTypedDict",
    "UsersGetByEmailRequest",
    "UsersGetByEmailRequestTypedDict",
    "UsersListRequest",
    "UsersListRequestTypedDict",
    "UsersSendEmailRequest",
    "UsersSendEmailRequestTypedDict",
    "ValidationError",
    "ValidationErrorTypedDict",
    "VoiceSampleCreateRequest",
    "VoiceSampleCreateRequestTypedDict",
]

_dynamic_imports: dict[str, str] = {
    "AgentDeleteRequest": ".agent_deleteop",
    "AgentDeleteRequestTypedDict": ".agent_deleteop",
    "AgentGetByIDRequest": ".agent_get_by_idop",
    "AgentGetByIDRequestTypedDict": ".agent_get_by_idop",
    "AgentListRequest": ".agent_listop",
    "AgentListRequestTypedDict": ".agent_listop",
    "AgentCreate": ".agentcreate",
    "AgentCreateTypedDict": ".agentcreate",
    "AgentLanguage": ".agentlanguage",
    "AgentLanguageTypedDict": ".agentlanguage",
    "AgentProperties": ".agentproperties",
    "AgentSttProvider": ".agentsttprovider",
    "AgentToolDefaults": ".agenttooldefaults",
    "AgentToolDefaultsTypedDict": ".agenttooldefaults",
    "AgentToolFieldDefault": ".agenttoolfielddefault",
    "AgentToolFieldDefaultTypedDict": ".agenttoolfielddefault",
    "AgentUpdate": ".agentupdate",
    "AgentUpdateTypedDict": ".agentupdate",
    "AgentVoice": ".agentvoice",
    "AgentVoiceTypedDict": ".agentvoice",
    "AgentVoiceDisplayName": ".agentvoicedisplayname",
    "AgentVoiceGender": ".agentvoicegender",
    "AgentVoiceModel": ".agentvoicemodel",
    "AgentVoiceVarName": ".agentvoicevarname",
    "AgentWaitSound": ".agentwaitsound",
    "AvailableTargetsRequest": ".available_targetsop",
    "AvailableTargetsRequestTypedDict": ".available_targetsop",
    "AvailableTarget": ".availabletarget",
    "AvailableTargetTypedDict": ".availabletarget",
    "AvailableTargetProperties": ".availabletargetproperties",
    "BatchDetails": ".batchdetails",
    "BatchDetailsTypedDict": ".batchdetails",
    "BatchProperties": ".batchproperties",
    "BatchStatus": ".batchstatus",
    "BodyInsightsFolderUploadFile": ".body_insights_folder_upload_file",
    "BodyInsightsFolderUploadFileFile": ".body_insights_folder_upload_file",
    "BodyInsightsFolderUploadFileFileTypedDict": ".body_insights_folder_upload_file",
    "BodyInsightsFolderUploadFileTypedDict": ".body_insights_folder_upload_file",
    "BodyOrganizationsCreate": ".body_organizations_create",
    "BodyOrganizationsCreateLogo": ".body_organizations_create",
    "BodyOrganizationsCreateLogoTypedDict": ".body_organizations_create",
    "BodyOrganizationsCreateTypedDict": ".body_organizations_create",
    "BodyOrganizationsDelete": ".body_organizations_delete",
    "BodyOrganizationsDeleteTypedDict": ".body_organizations_delete",
    "BodyOrganizationsUpdate": ".body_organizations_update",
    "BodyOrganizationsUpdateLogo": ".body_organizations_update",
    "BodyOrganizationsUpdateLogoTypedDict": ".body_organizations_update",
    "BodyOrganizationsUpdateTypedDict": ".body_organizations_update",
    "BodyOutboundBatchDelete": ".body_outbound_batch_delete",
    "BodyOutboundBatchDeleteTypedDict": ".body_outbound_batch_delete",
    "BodyOutboundBatchUpload": ".body_outbound_batch_upload",
    "BodyOutboundBatchUploadFile": ".body_outbound_batch_upload",
    "BodyOutboundBatchUploadFileTypedDict": ".body_outbound_batch_upload",
    "BodyOutboundBatchUploadTypedDict": ".body_outbound_batch_upload",
    "CampaignProperties": ".campaignproperties",
    "Channel": ".channel",
    "ChannelTypedDict": ".channel",
    "ChannelTargetsCreateRequest": ".channel_targets_createop",
    "ChannelTargetsCreateRequestTypedDict": ".channel_targets_createop",
    "ChannelTargetsDeleteRequest": ".channel_targets_deleteop",
    "ChannelTargetsDeleteRequestTypedDict": ".channel_targets_deleteop",
    "ChannelTargetsGetByIDRequest": ".channel_targets_get_by_idop",
    "ChannelTargetsGetByIDRequestTypedDict": ".channel_targets_get_by_idop",
    "ChannelTargetsListRequest": ".channel_targets_listop",
    "ChannelTargetsListRequestTypedDict": ".channel_targets_listop",
    "ChannelTargetsUpdateRequest": ".channel_targets_updateop",
    "ChannelTargetsUpdateRequestTypedDict": ".channel_targets_updateop",
    "ChannelConfigView": ".channelconfigview",
    "ChannelConfigViewTypedDict": ".channelconfigview",
    "ChannelProperties": ".channelproperties",
    "ChannelsListRequest": ".channels_listop",
    "ChannelsListRequestTypedDict": ".channels_listop",
    "ChannelsTwilioGetByIDRequest": ".channels_twilio_get_by_idop",
    "ChannelsTwilioGetByIDRequestTypedDict": ".channels_twilio_get_by_idop",
    "ChannelsTwilioNumbersAddRequest": ".channels_twilio_numbers_addop",
    "ChannelsTwilioNumbersAddRequestTypedDict": ".channels_twilio_numbers_addop",
    "ChannelsTwilioNumbersListRequest": ".channels_twilio_numbers_listop",
    "ChannelsTwilioNumbersListRequestTypedDict": ".channels_twilio_numbers_listop",
    "ChannelsTwilioNumbersUpdateRequest": ".channels_twilio_numbers_updateop",
    "ChannelsTwilioNumbersUpdateRequestTypedDict": ".channels_twilio_numbers_updateop",
    "ChannelServices": ".channelservices",
    "ChannelTargetCreateRequest": ".channeltargetcreaterequest",
    "ChannelTargetCreateRequestTypedDict": ".channeltargetcreaterequest",
    "ChannelTargetProperties": ".channeltargetproperties",
    "ChannelTargetUpdateRequest": ".channeltargetupdaterequest",
    "ChannelTargetUpdateRequestTypedDict": ".channeltargetupdaterequest",
    "CommunicationBatch": ".communicationbatch",
    "CommunicationBatchTypedDict": ".communicationbatch",
    "CommunicationBatchInput": ".communicationbatchinput",
    "CommunicationBatchInputTypedDict": ".communicationbatchinput",
    "CommunicationBatchUpdate": ".communicationbatchupdate",
    "CommunicationBatchUpdateTypedDict": ".communicationbatchupdate",
    "CommunicationRequest": ".communicationrequest",
    "CommunicationRequestTypedDict": ".communicationrequest",
    "CommunicationRequestResult": ".communicationrequestresult",
    "CommunicationRequestResultTypedDict": ".communicationrequestresult",
    "Insights": ".communicationrequestresult",
    "InsightsTypedDict": ".communicationrequestresult",
    "Conversation": ".conversation",
    "ConversationTypedDict": ".conversation",
    "ConversationProperties": ".conversationproperties",
    "ConversationsListRequest": ".conversations_listop",
    "ConversationsListRequestTypedDict": ".conversations_listop",
    "CreateTakeoutResponse": ".createtakeoutresponse",
    "CreateTakeoutResponseTypedDict": ".createtakeoutresponse",
    "CustomMessageGetByIDRequest": ".custom_message_get_by_idop",
    "CustomMessageGetByIDRequestTypedDict": ".custom_message_get_by_idop",
    "CustomMessagesDeleteRequest": ".custom_messages_deleteop",
    "CustomMessagesDeleteRequestTypedDict": ".custom_messages_deleteop",
    "CustomMessagesListRequest": ".custom_messages_listop",
    "CustomMessagesListRequestTypedDict": ".custom_messages_listop",
    "CustomMessageCreateRequest": ".custommessagecreaterequest",
    "CustomMessageCreateRequestTypedDict": ".custommessagecreaterequest",
    "CustomMessageProperties": ".custommessageproperties",
    "CustomMessageResponse": ".custommessageresponse",
    "CustomMessageResponseTypedDict": ".custommessageresponse",
    "CustomMessageRule": ".custommessagerule",
    "CustomMessageRuleTypedDict": ".custommessagerule",
    "CustomMessageUpdateRequest": ".custommessageupdaterequest",
    "CustomMessageUpdateRequestTypedDict": ".custommessageupdaterequest",
    "Dashboard": ".dashboard",
    "DashboardTypedDict": ".dashboard",
    "DashboardProperties": ".dashboardproperties",
    "DashboardResponse": ".dashboardresponse",
    "DashboardResponseTypedDict": ".dashboardresponse",
    "DashboardTokenResponse": ".dashboardtokenresponse",
    "DashboardTokenResponseTypedDict": ".dashboardtokenresponse",
    "DataSourcesDeleteRequest": ".data_sources_deleteop",
    "DataSourcesDeleteRequestTypedDict": ".data_sources_deleteop",
    "DataSourcesGetByIDRequest": ".data_sources_get_by_idop",
    "DataSourcesGetByIDRequestTypedDict": ".data_sources_get_by_idop",
    "DataSourcesListRequest": ".data_sources_listop",
    "DataSourcesListRequestTypedDict": ".data_sources_listop",
    "DataSourceCreateRequest": ".datasourcecreaterequest",
    "DataSourceCreateRequestTypedDict": ".datasourcecreaterequest",
    "DataSourceDetailResponse": ".datasourcedetailresponse",
    "DataSourceDetailResponseTypedDict": ".datasourcedetailresponse",
    "DataSourceMetadataResponse": ".datasourcemetadataresponse",
    "DataSourceMetadataResponseTypedDict": ".datasourcemetadataresponse",
    "DataSourceProperties": ".datasourceproperties",
    "DataSourceUpdateRequest": ".datasourceupdaterequest",
    "DataSourceUpdateRequestTypedDict": ".datasourceupdaterequest",
    "DayOfWeek": ".dayofweek",
    "DaysOfWeek": ".daysofweek",
    "DialogMessage": ".dialogmessage",
    "DialogMessageTypedDict": ".dialogmessage",
    "DialogRole": ".dialogrole",
    "DialogToolCall": ".dialogtoolcall",
    "DialogToolCallTypedDict": ".dialogtoolcall",
    "Attributes": ".event",
    "AttributesTypedDict": ".event",
    "Event": ".event",
    "EventTypedDict": ".event",
    "EventProperties": ".eventproperties",
    "EventsListRequest": ".events_listop",
    "EventsListRequestTypedDict": ".events_listop",
    "FolderDetails": ".folderdetails",
    "FolderDetailsTypedDict": ".folderdetails",
    "FolderStats": ".folderdetails",
    "FolderStatsTypedDict": ".folderdetails",
    "GenerateSessionRecordingUrlsRequest": ".generate_session_recording_urlsop",
    "GenerateSessionRecordingUrlsRequestTypedDict": ".generate_session_recording_urlsop",
    "GetSessionDataBySessionIDRequest": ".get_session_data_by_session_idop",
    "GetSessionDataBySessionIDRequestTypedDict": ".get_session_data_by_session_idop",
    "GetSessionDataBySidRequest": ".get_session_data_by_sidop",
    "GetSessionDataBySidRequestTypedDict": ".get_session_data_by_sidop",
    "GetSessionToolCallResultByIDRequest": ".get_session_tool_call_result_by_idop",
    "GetSessionToolCallResultByIDRequestTypedDict": ".get_session_tool_call_result_by_idop",
    "IncidentDeleteRequest": ".incident_deleteop",
    "IncidentDeleteRequestTypedDict": ".incident_deleteop",
    "IncidentGetByIDRequest": ".incident_get_by_idop",
    "IncidentGetByIDRequestTypedDict": ".incident_get_by_idop",
    "IncidentListRequest": ".incident_listop",
    "IncidentListRequestTypedDict": ".incident_listop",
    "IncidentCreateRequest": ".incidentcreaterequest",
    "IncidentCreateRequestTypedDict": ".incidentcreaterequest",
    "IncidentOrganizationResponse": ".incidentorganizationresponse",
    "IncidentOrganizationResponseTypedDict": ".incidentorganizationresponse",
    "IncidentProperties": ".incidentproperties",
    "IncidentResponse": ".incidentresponse",
    "IncidentResponseTypedDict": ".incidentresponse",
    "IncidentUpdateRequest": ".incidentupdaterequest",
    "IncidentUpdateRequestTypedDict": ".incidentupdaterequest",
    "InsightToolGetByIDRequest": ".insight_tool_get_by_idop",
    "InsightToolGetByIDRequestTypedDict": ".insight_tool_get_by_idop",
    "InsightToolListRequest": ".insight_tool_listop",
    "InsightToolListRequestTypedDict": ".insight_tool_listop",
    "InsightsFolderDeleteRequest": ".insights_folder_deleteop",
    "InsightsFolderDeleteRequestTypedDict": ".insights_folder_deleteop",
    "InsightsFolderGetByIDRequest": ".insights_folder_get_by_idop",
    "InsightsFolderGetByIDRequestTypedDict": ".insights_folder_get_by_idop",
    "InsightsFolderListRequest": ".insights_folder_listop",
    "InsightsFolderListRequestTypedDict": ".insights_folder_listop",
    "InsightsFolderUpdateRequest": ".insights_folder_updateop",
    "InsightsFolderUpdateRequestTypedDict": ".insights_folder_updateop",
    "InsightsFolderUploadFileRequest": ".insights_folder_upload_fileop",
    "InsightsFolderUploadFileRequestTypedDict": ".insights_folder_upload_fileop",
    "InsightsListRequest": ".insights_listop",
    "InsightsListRequestTypedDict": ".insights_listop",
    "InsightsToolDeleteRequest": ".insights_tool_deleteop",
    "InsightsToolDeleteRequestTypedDict": ".insights_tool_deleteop",
    "InsightsToolUpdateRequest": ".insights_tool_updateop",
    "InsightsToolUpdateRequestTypedDict": ".insights_tool_updateop",
    "InsightsUploadListFilesRequest": ".insights_upload_list_filesop",
    "InsightsUploadListFilesRequestTypedDict": ".insights_upload_list_filesop",
    "InsightsUploadMoveFilesRequest": ".insights_upload_move_filesop",
    "InsightsUploadMoveFilesRequestTypedDict": ".insights_upload_move_filesop",
    "InsightsWorkflowActivateRequest": ".insights_workflow_activateop",
    "InsightsWorkflowActivateRequestTypedDict": ".insights_workflow_activateop",
    "InsightsWorkflowDeleteRequest": ".insights_workflow_deleteop",
    "InsightsWorkflowDeleteRequestTypedDict": ".insights_workflow_deleteop",
    "InsightsWorkflowGetByIDRequest": ".insights_workflow_get_by_idop",
    "InsightsWorkflowGetByIDRequestTypedDict": ".insights_workflow_get_by_idop",
    "InsightsWorkflowInactivateRequest": ".insights_workflow_inactivateop",
    "InsightsWorkflowInactivateRequestTypedDict": ".insights_workflow_inactivateop",
    "InsightsWorkflowListRequest": ".insights_workflow_listop",
    "InsightsWorkflowListRequestTypedDict": ".insights_workflow_listop",
    "InsightsWorkflowUpdateRequest": ".insights_workflow_updateop",
    "InsightsWorkflowUpdateRequestTypedDict": ".insights_workflow_updateop",
    "InsightsFolder": ".insightsfolder",
    "InsightsFolderTypedDict": ".insightsfolder",
    "InsightsFolderFileMove": ".insightsfolderfilemove",
    "InsightsFolderFileMoveTypedDict": ".insightsfolderfilemove",
    "InsightsFolderInput": ".insightsfolderinput",
    "InsightsFolderInputTypedDict": ".insightsfolderinput",
    "InsightsFolderProperties": ".insightsfolderproperties",
    "InsightsOutput": ".insightsoutput",
    "InsightsOutputTypedDict": ".insightsoutput",
    "JSONValue": ".insightsoutput",
    "JSONValueTypedDict": ".insightsoutput",
    "InsightsProperties": ".insightsproperties",
    "InsightsUploadFile": ".insightsuploadfile",
    "InsightsUploadFileTypedDict": ".insightsuploadfile",
    "Metadata": ".insightsuploadfile",
    "MetadataTypedDict": ".insightsuploadfile",
    "InsightsUploadFileProperties": ".insightsuploadfileproperties",
    "InsightsWorkflowQueueSession": ".insightsworkflowqueuesession",
    "InsightsWorkflowQueueSessionTypedDict": ".insightsworkflowqueuesession",
    "InsightToolDefinition": ".insighttooldefinition",
    "InsightToolDefinitionTypedDict": ".insighttooldefinition",
    "InsightToolInput": ".insighttoolinput",
    "InsightToolInputTypedDict": ".insighttoolinput",
    "InsightToolOutput": ".insighttooloutput",
    "InsightToolOutputTypedDict": ".insighttooloutput",
    "InsightToolProperties": ".insighttoolproperties",
    "InsightToolTestInput": ".insighttooltestinput",
    "InsightToolTestInputTypedDict": ".insighttooltestinput",
    "InsightWorkflowActivate": ".insightworkflowactivate",
    "InsightWorkflowActivateTypedDict": ".insightworkflowactivate",
    "AgentList": ".insightworkflowcondition",
    "AgentListTypedDict": ".insightworkflowcondition",
    "InsightWorkflowCondition": ".insightworkflowcondition",
    "InsightWorkflowConditionTypedDict": ".insightworkflowcondition",
    "SampleRate": ".insightworkflowcondition",
    "SampleRateTypedDict": ".insightworkflowcondition",
    "InsightWorkflowEstimate": ".insightworkflowestimate",
    "InsightWorkflowEstimateTypedDict": ".insightworkflowestimate",
    "InsightWorkflowInput": ".insightworkflowinput",
    "InsightWorkflowInputTypedDict": ".insightworkflowinput",
    "InsightWorkflowOutput": ".insightworkflowoutput",
    "InsightWorkflowOutputTypedDict": ".insightworkflowoutput",
    "InsightWorkflowProperties": ".insightworkflowproperties",
    "InspectLatencyResponse": ".inspectlatencyresponse",
    "InspectLatencyResponseTypedDict": ".inspectlatencyresponse",
    "InternalTool": ".internaltool",
    "InternalToolTypedDict": ".internaltool",
    "LanguageGroupsDeleteRequest": ".language_groups_deleteop",
    "LanguageGroupsDeleteRequestTypedDict": ".language_groups_deleteop",
    "LanguageGroupsGetByIDRequest": ".language_groups_get_by_idop",
    "LanguageGroupsGetByIDRequestTypedDict": ".language_groups_get_by_idop",
    "LanguageGroupsListRequest": ".language_groups_listop",
    "LanguageGroupsListRequestTypedDict": ".language_groups_listop",
    "LanguageCode": ".languagecode",
    "LanguageConfig": ".languageconfig",
    "LanguageConfigTypedDict": ".languageconfig",
    "LanguageGroupAgentInfo": ".languagegroupagentinfo",
    "LanguageGroupAgentInfoTypedDict": ".languagegroupagentinfo",
    "LanguageGroupCreateRequest": ".languagegroupcreaterequest",
    "LanguageGroupCreateRequestTypedDict": ".languagegroupcreaterequest",
    "LanguageGroupProperties": ".languagegroupproperties",
    "LanguageGroupResponse": ".languagegroupresponse",
    "LanguageGroupResponseTypedDict": ".languagegroupresponse",
    "LanguageGroupUpdateRequest": ".languagegroupupdaterequest",
    "LanguageGroupUpdateRequestTypedDict": ".languagegroupupdaterequest",
    "LatencyCategory": ".latencycategory",
    "LatencyEntry": ".latencyentry",
    "LatencyEntryTypedDict": ".latencyentry",
    "LatencyUnitType": ".latencyunittype",
    "ListResponseAgentResponse": ".listresponse_agentresponse_",
    "ListResponseAgentResponseTypedDict": ".listresponse_agentresponse_",
    "ListResponseAvailableTarget": ".listresponse_availabletarget_",
    "ListResponseAvailableTargetTypedDict": ".listresponse_availabletarget_",
    "ListResponseChannel": ".listresponse_channel_",
    "ListResponseChannelTypedDict": ".listresponse_channel_",
    "ListResponseChannelTargetResponse": ".listresponse_channeltargetresponse_",
    "ListResponseChannelTargetResponseTypedDict": ".listresponse_channeltargetresponse_",
    "ListResponseCommunicationBatch": ".listresponse_communicationbatch_",
    "ListResponseCommunicationBatchTypedDict": ".listresponse_communicationbatch_",
    "ListResponseConversation": ".listresponse_conversation_",
    "ListResponseConversationTypedDict": ".listresponse_conversation_",
    "ListResponseCustomMessageResponse": ".listresponse_custommessageresponse_",
    "ListResponseCustomMessageResponseTypedDict": ".listresponse_custommessageresponse_",
    "ListResponseDashboardResponse": ".listresponse_dashboardresponse_",
    "ListResponseDashboardResponseTypedDict": ".listresponse_dashboardresponse_",
    "ListResponseDataSourceMetadataResponse": ".listresponse_datasourcemetadataresponse_",
    "ListResponseDataSourceMetadataResponseTypedDict": ".listresponse_datasourcemetadataresponse_",
    "ListResponseEvent": ".listresponse_event_",
    "ListResponseEventTypedDict": ".listresponse_event_",
    "ListResponseIncidentResponse": ".listresponse_incidentresponse_",
    "ListResponseIncidentResponseTypedDict": ".listresponse_incidentresponse_",
    "ListResponseInsightsFolder": ".listresponse_insightsfolder_",
    "ListResponseInsightsFolderTypedDict": ".listresponse_insightsfolder_",
    "ListResponseInsightsOutput": ".listresponse_insightsoutput_",
    "ListResponseInsightsOutputTypedDict": ".listresponse_insightsoutput_",
    "ListResponseInsightsUploadFile": ".listresponse_insightsuploadfile_",
    "ListResponseInsightsUploadFileTypedDict": ".listresponse_insightsuploadfile_",
    "ListResponseInsightToolOutput": ".listresponse_insighttooloutput_",
    "ListResponseInsightToolOutputTypedDict": ".listresponse_insighttooloutput_",
    "ListResponseInsightWorkflowOutput": ".listresponse_insightworkflowoutput_",
    "ListResponseInsightWorkflowOutputTypedDict": ".listresponse_insightworkflowoutput_",
    "ListResponseLanguageGroupResponse": ".listresponse_languagegroupresponse_",
    "ListResponseLanguageGroupResponseTypedDict": ".listresponse_languagegroupresponse_",
    "ListResponseOutboundCampaign": ".listresponse_outboundcampaign_",
    "ListResponseOutboundCampaignTypedDict": ".listresponse_outboundcampaign_",
    "ListResponsePromptResponse": ".listresponse_promptresponse_",
    "ListResponsePromptResponseTypedDict": ".listresponse_promptresponse_",
    "ListResponseRoleResponse": ".listresponse_roleresponse_",
    "ListResponseRoleResponseTypedDict": ".listresponse_roleresponse_",
    "ListResponseServiceResponse": ".listresponse_serviceresponse_",
    "ListResponseServiceResponseTypedDict": ".listresponse_serviceresponse_",
    "ListResponseSession": ".listresponse_session_",
    "ListResponseSessionTypedDict": ".listresponse_session_",
    "ListResponseSessionLabel": ".listresponse_sessionlabel_",
    "ListResponseSessionLabelTypedDict": ".listresponse_sessionlabel_",
    "ListResponseToolResponse": ".listresponse_toolresponse_",
    "ListResponseToolResponseTypedDict": ".listresponse_toolresponse_",
    "ListResponseUserResponse": ".listresponse_userresponse_",
    "ListResponseUserResponseTypedDict": ".listresponse_userresponse_",
    "LoginType": ".logintype",
    "OrderByDirection": ".orderbydirection",
    "OrganizationChannelConfig": ".organizationchannelconfig",
    "OrganizationChannelConfigTypedDict": ".organizationchannelconfig",
    "OrganizationChannelCreateRequest": ".organizationchannelcreaterequest",
    "OrganizationChannelCreateRequestTypedDict": ".organizationchannelcreaterequest",
    "OrganizationChannelUpdateRequest": ".organizationchannelupdaterequest",
    "OrganizationChannelUpdateRequestTypedDict": ".organizationchannelupdaterequest",
    "OrganizationResponse": ".organizationresponse",
    "OrganizationResponseTypedDict": ".organizationresponse",
    "OutboundBatchAddRequest": ".outbound_batch_addop",
    "OutboundBatchAddRequestTypedDict": ".outbound_batch_addop",
    "OutboundBatchDeleteRequest": ".outbound_batch_deleteop",
    "OutboundBatchDeleteRequestTypedDict": ".outbound_batch_deleteop",
    "OutboundBatchGetByIDRequest": ".outbound_batch_get_by_idop",
    "OutboundBatchGetByIDRequestTypedDict": ".outbound_batch_get_by_idop",
    "OutboundBatchListRequest": ".outbound_batch_listop",
    "OutboundBatchListRequestTypedDict": ".outbound_batch_listop",
    "OutboundBatchRemoveRequest": ".outbound_batch_removeop",
    "OutboundBatchRemoveRequestTypedDict": ".outbound_batch_removeop",
    "OutboundBatchResultsRequest": ".outbound_batch_resultsop",
    "OutboundBatchResultsRequestTypedDict": ".outbound_batch_resultsop",
    "OutboundBatchUpdateRequest": ".outbound_batch_updateop",
    "OutboundBatchUpdateRequestTypedDict": ".outbound_batch_updateop",
    "OutboundBatchUploadRequest": ".outbound_batch_uploadop",
    "OutboundBatchUploadRequestTypedDict": ".outbound_batch_uploadop",
    "OutboundCampaignDeleteRequest": ".outbound_campaign_deleteop",
    "OutboundCampaignDeleteRequestTypedDict": ".outbound_campaign_deleteop",
    "OutboundCampaignGetByIDRequest": ".outbound_campaign_get_by_idop",
    "OutboundCampaignGetByIDRequestTypedDict": ".outbound_campaign_get_by_idop",
    "OutboundCampaignListRequest": ".outbound_campaign_listop",
    "OutboundCampaignListRequestTypedDict": ".outbound_campaign_listop",
    "OutboundCampaignUpdateRequest": ".outbound_campaign_updateop",
    "OutboundCampaignUpdateRequestTypedDict": ".outbound_campaign_updateop",
    "OutboundCampaign": ".outboundcampaign",
    "OutboundCampaignTypedDict": ".outboundcampaign",
    "OutboundCampaignInput": ".outboundcampaigninput",
    "OutboundCampaignInputTypedDict": ".outboundcampaigninput",
    "PermissionGroupResponse": ".permissiongroupresponse",
    "PermissionGroupResponseTypedDict": ".permissiongroupresponse",
    "PermissionResponse": ".permissionresponse",
    "PermissionResponseTypedDict": ".permissionresponse",
    "PostGetDashboardRequest": ".post_get_dashboardop",
    "PostGetDashboardRequestTypedDict": ".post_get_dashboardop",
    "PostListDashboardRequest": ".post_list_dashboardop",
    "PostListDashboardRequestTypedDict": ".post_list_dashboardop",
    "PromptCreateRequest": ".promptcreaterequest",
    "PromptCreateRequestTypedDict": ".promptcreaterequest",
    "PromptHistory": ".prompthistory",
    "PromptHistoryTypedDict": ".prompthistory",
    "PromptHistoryLinkedTool": ".prompthistorylinkedtool",
    "PromptHistoryLinkedToolTypedDict": ".prompthistorylinkedtool",
    "PromptLlmConfig": ".promptllmconfig",
    "PromptLlmConfigTypedDict": ".promptllmconfig",
    "PromptLlmProvider": ".promptllmprovider",
    "PromptProperties": ".promptproperties",
    "PromptResponse": ".promptresponse",
    "PromptResponseTypedDict": ".promptresponse",
    "PromptsDeleteRequest": ".prompts_deleteop",
    "PromptsDeleteRequestTypedDict": ".prompts_deleteop",
    "PromptsGetByIDRequest": ".prompts_get_by_idop",
    "PromptsGetByIDRequestTypedDict": ".prompts_get_by_idop",
    "PromptsHistoryRequest": ".prompts_historyop",
    "PromptsHistoryRequestTypedDict": ".prompts_historyop",
    "PromptsListRequest": ".prompts_listop",
    "PromptsListRequestTypedDict": ".prompts_listop",
    "PromptUpdateRequest": ".promptupdaterequest",
    "PromptUpdateRequestTypedDict": ".promptupdaterequest",
    "RequestStatus": ".requeststatus",
    "RoleCreateRequest": ".rolecreaterequest",
    "RoleCreateRequestTypedDict": ".rolecreaterequest",
    "RoleProperties": ".roleproperties",
    "RoleResponse": ".roleresponse",
    "RoleResponseTypedDict": ".roleresponse",
    "RolesDeleteRequest": ".roles_deleteop",
    "RolesDeleteRequestTypedDict": ".roles_deleteop",
    "RolesGetByIDRequest": ".roles_get_by_idop",
    "RolesGetByIDRequestTypedDict": ".roles_get_by_idop",
    "RolesListRequest": ".roles_listop",
    "RolesListRequestTypedDict": ".roles_listop",
    "RoleUpdateRequest": ".roleupdaterequest",
    "RoleUpdateRequestTypedDict": ".roleupdaterequest",
    "Security": ".security",
    "SecurityTypedDict": ".security",
    "ServiceDeleteRequest": ".service_deleteop",
    "ServiceDeleteRequestTypedDict": ".service_deleteop",
    "ServiceListRequest": ".service_listop",
    "ServiceListRequestTypedDict": ".service_listop",
    "ServiceCreateRequest": ".servicecreaterequest",
    "ServiceCreateRequestTypedDict": ".servicecreaterequest",
    "ServiceProperties": ".serviceproperties",
    "ServiceResponse": ".serviceresponse",
    "ServiceResponseTypedDict": ".serviceresponse",
    "ServicesGetByIDRequest": ".services_get_by_idop",
    "ServicesGetByIDRequestTypedDict": ".services_get_by_idop",
    "ServiceUpdateRequest": ".serviceupdaterequest",
    "ServiceUpdateRequestTypedDict": ".serviceupdaterequest",
    "Session": ".session",
    "SessionTypedDict": ".session",
    "SessionFullSummaryGetByIDRequest": ".session_full_summary_get_by_idop",
    "SessionFullSummaryGetByIDRequestTypedDict": ".session_full_summary_get_by_idop",
    "SessionGetByIDRequest": ".session_get_by_idop",
    "SessionGetByIDRequestTypedDict": ".session_get_by_idop",
    "SessionLabelGetByIDRequest": ".session_label_get_by_idop",
    "SessionLabelGetByIDRequestTypedDict": ".session_label_get_by_idop",
    "SessionLabelsListRequest": ".session_labels_listop",
    "SessionLabelsListRequestTypedDict": ".session_labels_listop",
    "SessionLatencyGetByIDRequest": ".session_latency_get_by_idop",
    "SessionLatencyGetByIDRequestTypedDict": ".session_latency_get_by_idop",
    "SessionRecordingStreamRequest": ".session_recording_streamop",
    "SessionRecordingStreamRequestTypedDict": ".session_recording_streamop",
    "SessionTranscriptGetByIDRequest": ".session_transcript_get_by_idop",
    "SessionTranscriptGetByIDRequestTypedDict": ".session_transcript_get_by_idop",
    "SessionAction": ".sessionaction",
    "SessionActionTypedDict": ".sessionaction",
    "SessionData": ".sessiondata",
    "SessionDataTypedDict": ".sessiondata",
    "SessionLabel": ".sessionlabel",
    "SessionLabelTypedDict": ".sessionlabel",
    "SessionLabelCreate": ".sessionlabelcreate",
    "SessionLabelCreateTypedDict": ".sessionlabelcreate",
    "SessionLabelProperties": ".sessionlabelproperties",
    "SessionMessage": ".sessionmessage",
    "SessionMessageTypedDict": ".sessionmessage",
    "SessionProperties": ".sessionproperties",
    "SessionRecordingResponse": ".sessionrecordingresponse",
    "SessionRecordingResponseTypedDict": ".sessionrecordingresponse",
    "SessionsListRequest": ".sessions_listop",
    "SessionsListRequestTypedDict": ".sessions_listop",
    "SessionSummaryResponse": ".sessionsummaryresponse",
    "SessionSummaryResponseTypedDict": ".sessionsummaryresponse",
    "SessionText": ".sessiontext",
    "SessionTextTypedDict": ".sessiontext",
    "SessionTranscriptionResponse": ".sessiontranscriptionresponse",
    "SessionTranscriptionResponseTypedDict": ".sessiontranscriptionresponse",
    "StaticToolParameter": ".statictoolparameter",
    "StaticToolParameterTypedDict": ".statictoolparameter",
    "StaticToolParameterType": ".statictoolparametertype",
    "SummaryEntry": ".summaryentry",
    "SummaryEntryTypedDict": ".summaryentry",
    "SupportedLlm": ".supportedllm",
    "SupportedLlmTypedDict": ".supportedllm",
    "TakeoutRequestStatus": ".takeoutrequeststatus",
    "TakeoutsGetByJobIDRequest": ".takeouts_get_by_job_idop",
    "TakeoutsGetByJobIDRequestTypedDict": ".takeouts_get_by_job_idop",
    "TakeoutsGetFileRequest": ".takeouts_get_fileop",
    "TakeoutsGetFileRequestTypedDict": ".takeouts_get_fileop",
    "TakeoutStatusResponse": ".takeoutstatusresponse",
    "TakeoutStatusResponseTypedDict": ".takeoutstatusresponse",
    "TargetModes": ".targetmodes",
    "TelephonyConfigurations": ".telephonyconfigurations",
    "TelephonyConfigurationsTypedDict": ".telephonyconfigurations",
    "TestMessage": ".testmessage",
    "TestMessageTypedDict": ".testmessage",
    "TestMessageResponse": ".testmessageresponse",
    "TestMessageResponseTypedDict": ".testmessageresponse",
    "ToolDeleteRequest": ".tool_deleteop",
    "ToolDeleteRequestTypedDict": ".tool_deleteop",
    "ToolGetByNameRequest": ".tool_get_by_nameop",
    "ToolGetByNameRequestTypedDict": ".tool_get_by_nameop",
    "ToolListRequest": ".tool_listop",
    "ToolListRequestTypedDict": ".tool_listop",
    "ToolAgentInfo": ".toolagentinfo",
    "ToolAgentInfoTypedDict": ".toolagentinfo",
    "ToolArgumentLocation": ".toolargumentlocation",
    "ToolAuthType": ".toolauthtype",
    "ToolCreateRequest": ".toolcreaterequest",
    "ToolCreateRequestTypedDict": ".toolcreaterequest",
    "Defaults": ".tooldefinition",
    "DefaultsTypedDict": ".tooldefinition",
    "ToolDefinition": ".tooldefinition",
    "ToolDefinitionTypedDict": ".tooldefinition",
    "Type": ".tooldefinition",
    "ToolDetailResponse": ".tooldetailresponse",
    "ToolDetailResponseTypedDict": ".tooldetailresponse",
    "ToolFunction": ".toolfunction",
    "ToolFunctionTypedDict": ".toolfunction",
    "ToolHTTPEndpoint": ".toolhttpendpoint",
    "ToolHTTPEndpointTypedDict": ".toolhttpendpoint",
    "ToolHTTPMethod": ".toolhttpmethod",
    "ToolOptions": ".tooloptions",
    "ToolOptionsTypedDict": ".tooloptions",
    "ToolParameterDefault": ".toolparameterdefault",
    "ToolParameterDefaultTypedDict": ".toolparameterdefault",
    "Action": ".toolparametertransform",
    "ToolParameterTransform": ".toolparametertransform",
    "ToolParameterTransformTypedDict": ".toolparametertransform",
    "ToolParameterTransformCondition": ".toolparametertransformcondition",
    "ToolParameterTransformConditionTypedDict": ".toolparametertransformcondition",
    "ToolPromptInfo": ".toolpromptinfo",
    "ToolPromptInfoTypedDict": ".toolpromptinfo",
    "ToolProperties": ".toolproperties",
    "ToolResponse": ".toolresponse",
    "ToolResponseTypedDict": ".toolresponse",
    "ToolResultData": ".toolresultdata",
    "ToolResultDataTypedDict": ".toolresultdata",
    "ToolUpdateRequest": ".toolupdaterequest",
    "ToolUpdateRequestTypedDict": ".toolupdaterequest",
    "TtsProvider": ".ttsprovider",
    "TwilioChannelConfigCreate": ".twiliochannelconfigcreate",
    "TwilioChannelConfigCreateTypedDict": ".twiliochannelconfigcreate",
    "TwilioChannelConfigUpdate": ".twiliochannelconfigupdate",
    "TwilioChannelConfigUpdateTypedDict": ".twiliochannelconfigupdate",
    "TwilioChannelCreateRequest": ".twiliochannelcreaterequest",
    "TwilioChannelCreateRequestTypedDict": ".twiliochannelcreaterequest",
    "TwilioChannelUpdateRequest": ".twiliochannelupdaterequest",
    "TwilioChannelUpdateRequestTypedDict": ".twiliochannelupdaterequest",
    "TwilioListNumbersResponse": ".twiliolistnumbersresponse",
    "TwilioListNumbersResponseTypedDict": ".twiliolistnumbersresponse",
    "TwilioNumberAddRequest": ".twilionumberaddrequest",
    "TwilioNumberAddRequestTypedDict": ".twilionumberaddrequest",
    "TwilioNumberAddResponse": ".twilionumberaddresponse",
    "TwilioNumberAddResponseTypedDict": ".twilionumberaddresponse",
    "TwilioNumberUpdateRequest": ".twilionumberupdaterequest",
    "TwilioNumberUpdateRequestTypedDict": ".twilionumberupdaterequest",
    "TwilioNumberUpdateResponse": ".twilionumberupdateresponse",
    "TwilioNumberUpdateResponseTypedDict": ".twilionumberupdateresponse",
    "TwilioPhoneNumber": ".twiliophonenumber",
    "TwilioPhoneNumberTypedDict": ".twiliophonenumber",
    "UserActivityStatus": ".useractivitystatus",
    "UserCreateRequest": ".usercreaterequest",
    "UserCreateRequestTypedDict": ".usercreaterequest",
    "UserDeleteRequest": ".userdeleterequest",
    "UserDeleteRequestTypedDict": ".userdeleterequest",
    "UserProperties": ".userproperties",
    "UserResponse": ".userresponse",
    "UserResponseTypedDict": ".userresponse",
    "UsersGetByEmailRequest": ".users_get_by_emailop",
    "UsersGetByEmailRequestTypedDict": ".users_get_by_emailop",
    "UsersListRequest": ".users_listop",
    "UsersListRequestTypedDict": ".users_listop",
    "UsersSendEmailRequest": ".users_send_emailop",
    "UsersSendEmailRequestTypedDict": ".users_send_emailop",
    "UserUpdateRequest": ".userupdaterequest",
    "UserUpdateRequestTypedDict": ".userupdaterequest",
    "Loc": ".validationerror",
    "LocTypedDict": ".validationerror",
    "ValidationError": ".validationerror",
    "ValidationErrorTypedDict": ".validationerror",
    "VoiceSampleCreateRequest": ".voicesamplecreaterequest",
    "VoiceSampleCreateRequestTypedDict": ".voicesamplecreaterequest",
}


def dynamic_import(modname, retries=3):
    for attempt in range(retries):
        try:
            return import_module(modname, __package__)
        except KeyError:
            # Clear any half-initialized module and retry
            sys.modules.pop(modname, None)
            if attempt == retries - 1:
                break
    raise KeyError(f"Failed to import module '{modname}' after {retries} attempts")


def __getattr__(attr_name: str) -> object:
    module_name = _dynamic_imports.get(attr_name)
    if module_name is None:
        raise AttributeError(
            f"No {attr_name} found in _dynamic_imports for module name -> {__name__} "
        )

    try:
        module = dynamic_import(module_name)
        result = getattr(module, attr_name)
        return result
    except ImportError as e:
        raise ImportError(
            f"Failed to import {attr_name} from {module_name}: {e}"
        ) from e
    except AttributeError as e:
        raise AttributeError(
            f"Failed to get {attr_name} from {module_name}: {e}"
        ) from e


def __dir__():
    lazy_attrs = builtins.list(_dynamic_imports.keys())
    return builtins.sorted(lazy_attrs)
