"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from datetime import datetime
from pydantic import model_serializer
from syllable_sdk.types import BaseModel, Nullable, UNSET_SENTINEL
from typing import Any
from typing_extensions import TypedDict


class DialogToolCallTypedDict(TypedDict):
    tool_call_id: str
    r"""Tool call ID"""
    tool_name: str
    r"""Tool name"""
    tool_arguments: Any
    r"""Tool arguments"""
    tool_result: Nullable[Any]
    r"""Tool result data (only included if tool has propagate_tool_result=true)"""
    timestamp: datetime
    r"""Tool call timestamp"""


class DialogToolCall(BaseModel):
    tool_call_id: str
    r"""Tool call ID"""

    tool_name: str
    r"""Tool name"""

    tool_arguments: Any
    r"""Tool arguments"""

    tool_result: Nullable[Any]
    r"""Tool result data (only included if tool has propagate_tool_result=true)"""

    timestamp: datetime
    r"""Tool call timestamp"""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = []
        nullable_fields = ["tool_result"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m
