"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class RequestStatus(str, Enum):
    r"""Status of a communication request."""

    PENDING = "PENDING"
    DUPLICATE = "DUPLICATE"
    INITIATED = "INITIATED"
    CONNECTED = "CONNECTED"
    FAILED = "FAILED"
    CANCELED = "CANCELED"
    INVALID = "INVALID"
