"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class ToolProperties(str, Enum):
    r"""Names of tool fields supported for filtering/sorting on list endpoint."""

    ID = "id"
    NAME = "name"
    SERVICE_NAME = "service_name"
    DEFINITION = "definition"
    SERVICE_ID = "service_id"
    UPDATED_AT = "updated_at"
    LAST_UPDATED_BY = "last_updated_by"
