"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .body_outbound_batch_delete import (
    BodyOutboundBatchDelete,
    BodyOutboundBatchDeleteTypedDict,
)
from syllable_sdk.types import BaseModel
from syllable_sdk.utils import FieldMetadata, PathParamMetadata, RequestMetadata
from typing_extensions import Annotated, TypedDict


class OutboundBatchDeleteRequestTypedDict(TypedDict):
    batch_id: str
    body_outbound_batch_delete: BodyOutboundBatchDeleteTypedDict


class OutboundBatchDeleteRequest(BaseModel):
    batch_id: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]

    body_outbound_batch_delete: Annotated[
        BodyOutboundBatchDelete,
        FieldMetadata(
            request=RequestMetadata(media_type="application/x-www-form-urlencoded")
        ),
    ]
