"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class PromptProperties(str, Enum):
    r"""Names of prompt fields supported for filtering/sorting on list endpoint."""

    ID = "id"
    NAME = "name"
    NAME_EXACT = "name_exact"
    DESCRIPTION = "description"
    NAME_DESCRIPTION = "name_description"
    CONTEXT = "context"
    TOOLS = "tools"
    LLM_CONFIG = "llm_config"
    LAST_UPDATED = "last_updated"
    LAST_UPDATED_BY = "last_updated_by"
    AGENT_COUNT = "agent_count"
