"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class SessionLabelProperties(str, Enum):
    TIMESTAMP = "timestamp"
    SESSION_ID = "session_id"
    TYPE = "type"
    CODE = "code"
    USER_EMAIL = "user_email"
    ISSUE_CATEGORIES = "issue_categories"
    SESSION_ID_LIST = "session_id_list"
