"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from syllable_sdk.types import BaseModel
from typing_extensions import TypedDict


class PromptHistoryLinkedToolTypedDict(TypedDict):
    r"""Record of a tool linked to a previous prompt version in the prompt history."""

    tool_id: int
    r"""ID of the tool"""
    current_tool_name: str
    r"""Current name of the tool (may have been different at the time the given version of the prompt was created)"""
    out_of_date: bool
    r"""Whether the tool has changed (not including being deleted) since the given version of the prompt was created"""
    deleted: bool
    r"""Whether the tool has been deleted since the given version of the prompt was created"""


class PromptHistoryLinkedTool(BaseModel):
    r"""Record of a tool linked to a previous prompt version in the prompt history."""

    tool_id: int
    r"""ID of the tool"""

    current_tool_name: str
    r"""Current name of the tool (may have been different at the time the given version of the prompt was created)"""

    out_of_date: bool
    r"""Whether the tool has changed (not including being deleted) since the given version of the prompt was created"""

    deleted: bool
    r"""Whether the tool has been deleted since the given version of the prompt was created"""
