"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from syllable_sdk.types import BaseModel
from typing import List
from typing_extensions import TypedDict


class InsightsFolderFileMoveTypedDict(TypedDict):
    r"""Request model to move files between insight upload folders."""

    destination_folder_id: int
    r"""System-assign folder ID"""
    file_id_list: List[int]
    r"""List of system-assigned IDs for the files to be moved"""


class InsightsFolderFileMove(BaseModel):
    r"""Request model to move files between insight upload folders."""

    destination_folder_id: int
    r"""System-assign folder ID"""

    file_id_list: List[int]
    r"""List of system-assigned IDs for the files to be moved"""
