"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .outboundcampaigninput import OutboundCampaignInput, OutboundCampaignInputTypedDict
from syllable_sdk.types import BaseModel
from syllable_sdk.utils import FieldMetadata, PathParamMetadata, RequestMetadata
from typing_extensions import Annotated, TypedDict


class OutboundCampaignUpdateRequestTypedDict(TypedDict):
    campaign_id: int
    outbound_campaign_input: OutboundCampaignInputTypedDict


class OutboundCampaignUpdateRequest(BaseModel):
    campaign_id: Annotated[
        int, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]

    outbound_campaign_input: Annotated[
        OutboundCampaignInput,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]
