"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .insightsfolderinput import InsightsFolderInput, InsightsFolderInputTypedDict
from syllable_sdk.types import BaseModel
from syllable_sdk.utils import FieldMetadata, PathParamMetadata, RequestMetadata
from typing_extensions import Annotated, TypedDict


class InsightsFolderUpdateRequestTypedDict(TypedDict):
    folder_id: int
    insights_folder_input: InsightsFolderInputTypedDict


class InsightsFolderUpdateRequest(BaseModel):
    folder_id: Annotated[
        int, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]

    insights_folder_input: Annotated[
        InsightsFolderInput,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]
