"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class ToolArgumentLocation(str, Enum):
    r"""The location of the argument in a tool HTTP request.
    'body' is used for JSON data in the POST request body.
    'form' is used for form data in the POST request body.
    'path' is used for URL path parameters.
    'query' is used for query parameters in the URL.
    """

    BODY = "body"
    FORM = "form"
    PATH = "path"
    QUERY = "query"
