"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class TtsProvider(str, Enum):
    r"""TTS provider for an agent voice."""

    OPEN_AI = "OpenAI"
    ELEVEN_LABS = "ElevenLabs"
    GOOGLE = "Google"
