"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class InsightToolProperties(str, Enum):
    ID = "id"
    NAME = "name"
    NAME_EXACT = "name_exact"
    DESCRIPTION = "description"
    TOOL_ARGUMENTS = "tool_arguments"
    INSIGHT_TOOL_DEFINITION_ID = "insight_tool_definition_id"
    UPDATED_AT = "updated_at"
