"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class ToolHTTPMethod(str, Enum):
    r"""The HTTP method to use for a tool HTTP request."""

    GET = "get"
    POST = "post"
