"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class AgentVoiceModel(str, Enum):
    r"""Model for an agent voice."""

    CHIRP_3_HD = "Chirp 3 HD"
    ELEVEN_FLASH_V2_5 = "eleven_flash_v2_5"
    NEURAL2 = "Neural2"
    STANDARD = "Standard"
    STUDIO = "Studio"
    WAVE_NET = "WaveNet"
    TTS_1 = "tts-1"
    GPT_4O_MINI_TTS = "gpt-4o-mini-tts"
