"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .latencyentry import LatencyEntry, LatencyEntryTypedDict
from .summaryentry import SummaryEntry, SummaryEntryTypedDict
from syllable_sdk.types import BaseModel
from typing import List, Optional
from typing_extensions import NotRequired, TypedDict


class InspectLatencyResponseTypedDict(TypedDict):
    r"""This is a report of the time spent in each operation during this session. It contains a timeline,
    which lists the operations in the order they were executed, and a summary, which aggregates the
    operations by category and sub-category.
    """

    session_id: str
    timeline: List[LatencyEntryTypedDict]
    summary: NotRequired[List[SummaryEntryTypedDict]]


class InspectLatencyResponse(BaseModel):
    r"""This is a report of the time spent in each operation during this session. It contains a timeline,
    which lists the operations in the order they were executed, and a summary, which aggregates the
    operations by category and sub-category.
    """

    session_id: str

    timeline: List[LatencyEntry]

    summary: Optional[List[SummaryEntry]] = None
