"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .insightworkflowestimate import (
    InsightWorkflowEstimate,
    InsightWorkflowEstimateTypedDict,
)
from syllable_sdk.types import BaseModel
from typing_extensions import TypedDict


class InsightWorkflowActivateTypedDict(TypedDict):
    r"""Request model to activate an insight workflow."""

    is_acknowledged: bool
    r"""Flag to indicate if the user has acknowledged the estimate"""
    estimate: InsightWorkflowEstimateTypedDict
    r"""Response model for an insight workflow."""


class InsightWorkflowActivate(BaseModel):
    r"""Request model to activate an insight workflow."""

    is_acknowledged: bool
    r"""Flag to indicate if the user has acknowledged the estimate"""

    estimate: InsightWorkflowEstimate
    r"""Response model for an insight workflow."""
