"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .body_outbound_batch_upload import (
    BodyOutboundBatchUpload,
    BodyOutboundBatchUploadTypedDict,
)
from syllable_sdk.types import BaseModel
from syllable_sdk.utils import FieldMetadata, PathParamMetadata, RequestMetadata
from typing import Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class OutboundBatchUploadRequestTypedDict(TypedDict):
    batch_id: str
    body_outbound_batch_upload: NotRequired[BodyOutboundBatchUploadTypedDict]


class OutboundBatchUploadRequest(BaseModel):
    batch_id: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]

    body_outbound_batch_upload: Annotated[
        Optional[BodyOutboundBatchUpload],
        FieldMetadata(request=RequestMetadata(media_type="multipart/form-data")),
    ] = None
