"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class TargetModes(str, Enum):
    r"""Available modes (communication methods) for channel targets."""

    VOICE = "voice"
    CHAT = "chat"
    SMS = "sms"
    EMAIL = "email"
