"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .sessionmessage import SessionMessage, SessionMessageTypedDict
from syllable_sdk.types import BaseModel
from typing import List
from typing_extensions import TypedDict


class SessionDataTypedDict(TypedDict):
    session_id: int
    r"""Session ID"""
    source: str
    r"""Session source"""
    target: str
    r"""Session target"""
    is_test: bool
    r"""Is test session"""
    messages: List[SessionMessageTypedDict]
    r"""Session messages"""


class SessionData(BaseModel):
    session_id: int
    r"""Session ID"""

    source: str
    r"""Session source"""

    target: str
    r"""Session target"""

    is_test: bool
    r"""Is test session"""

    messages: List[SessionMessage]
    r"""Session messages"""
