"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from syllable_sdk.types import BaseModel
from typing import Any
from typing_extensions import TypedDict


class ToolFunctionTypedDict(TypedDict):
    r"""A function available to an agent.

    See:
    - https://learn.microsoft.com/en-us/azure/ai-services/openai/how-to/function-calling
    """

    name: str
    r"""The name of the function/tool call."""
    description: str
    r"""The description of the tool."""
    parameters: Any
    r"""The JSON Schema of parameters of the function/tool call."""


class ToolFunction(BaseModel):
    r"""A function available to an agent.

    See:
    - https://learn.microsoft.com/en-us/azure/ai-services/openai/how-to/function-calling
    """

    name: str
    r"""The name of the function/tool call."""

    description: str
    r"""The description of the tool."""

    parameters: Any
    r"""The JSON Schema of parameters of the function/tool call."""
