"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from syllable_sdk.types import BaseModel
from syllable_sdk.utils import FieldMetadata
from typing_extensions import Annotated, TypedDict


class BodyOutboundBatchDeleteTypedDict(TypedDict):
    delete_reason: str


class BodyOutboundBatchDelete(BaseModel):
    delete_reason: Annotated[str, FieldMetadata(form=True)]
