"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from datetime import datetime
from syllable_sdk.types import BaseModel
from typing_extensions import TypedDict


class CreateTakeoutResponseTypedDict(TypedDict):
    job_id: str
    created_at: datetime


class CreateTakeoutResponse(BaseModel):
    job_id: str

    created_at: datetime
