"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from syllable_sdk.types import BaseModel
from typing_extensions import TypedDict


class UserDeleteRequestTypedDict(TypedDict):
    r"""Request model to delete a user."""

    email: str
    r"""The email address of the user to delete"""
    reason: str
    r"""The reason for deleting the user"""


class UserDeleteRequest(BaseModel):
    r"""Request model to delete a user."""

    email: str
    r"""The email address of the user to delete"""

    reason: str
    r"""The reason for deleting the user"""
