"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from syllable_sdk.types import BaseModel
from typing_extensions import TypedDict


class DashboardTypedDict(TypedDict):
    r"""Deprecated.  Please update to use DashboardTokenResponse.
    Basic information about a dashboard.
    """

    embedded_id: str
    r"""Superset embedded ID of the dashboard"""
    guest_token: str
    r"""Superset guest token of the dashboard"""
    name: str
    r"""Name of the dashboard"""
    superset_url: str
    r"""Superset URL of the dashboard"""


class Dashboard(BaseModel):
    r"""Deprecated.  Please update to use DashboardTokenResponse.
    Basic information about a dashboard.
    """

    embedded_id: str
    r"""Superset embedded ID of the dashboard"""

    guest_token: str
    r"""Superset guest token of the dashboard"""

    name: str
    r"""Name of the dashboard"""

    superset_url: str
    r"""Superset URL of the dashboard"""
