"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .permissionresponse import PermissionResponse, PermissionResponseTypedDict
from syllable_sdk.types import BaseModel
from typing import List
from typing_extensions import TypedDict


class PermissionGroupResponseTypedDict(TypedDict):
    r"""Information about a group of permissions related to the same feature."""

    name: str
    r"""Name of the permission group"""
    description: str
    r"""Description of the permission group"""
    permissions: List[PermissionResponseTypedDict]
    r"""Permissions in the group"""


class PermissionGroupResponse(BaseModel):
    r"""Information about a group of permissions related to the same feature."""

    name: str
    r"""Name of the permission group"""

    description: str
    r"""Description of the permission group"""

    permissions: List[PermissionResponse]
    r"""Permissions in the group"""
