"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from syllable_sdk.types import BaseModel
from typing import Any
from typing_extensions import TypedDict


class AgentToolFieldDefaultTypedDict(TypedDict):
    r"""Agent-level value for a static parameter on a tool, overriding the tool-level default if one
    exists.
    """

    field_name: str
    r"""The name of the field"""
    default_value: Any
    r"""The default value for the field"""


class AgentToolFieldDefault(BaseModel):
    r"""Agent-level value for a static parameter on a tool, overriding the tool-level default if one
    exists.
    """

    field_name: str
    r"""The name of the field"""

    default_value: Any
    r"""The default value for the field"""
