"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .sessionaction import SessionAction, SessionActionTypedDict
from .sessiontext import SessionText, SessionTextTypedDict
from syllable_sdk.types import BaseModel
from typing import List
from typing_extensions import TypedDict


class SessionTranscriptionResponseTypedDict(TypedDict):
    r"""Text transcript of a given session. For more information, see
    [Console docs](https://docs.syllable.ai/workspaces/Sessions).
    """

    session_id: str
    r"""Internal ID of the session"""
    transcription: List[SessionTextTypedDict]
    r"""Transcriptions of all messages in the session"""
    actions: List[SessionActionTypedDict]
    r"""Tool invocations that occurred during the session"""


class SessionTranscriptionResponse(BaseModel):
    r"""Text transcript of a given session. For more information, see
    [Console docs](https://docs.syllable.ai/workspaces/Sessions).
    """

    session_id: str
    r"""Internal ID of the session"""

    transcription: List[SessionText]
    r"""Transcriptions of all messages in the session"""

    actions: List[SessionAction]
    r"""Tool invocations that occurred during the session"""
