"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class ChannelProperties(str, Enum):
    r"""Names of channel fields supported for filtering/sorting on list endpoint."""

    ID = "id"
    NAME = "name"
    NAME_EXACT = "name_exact"
    CHANNEL_SERVICE = "channel_service"
    SUPPORTED_MODES = "supported_modes"
