"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class AgentSttProvider(str, Enum):
    r"""Speech-to-text providers supported by agents."""

    GOOGLE_STT_V2_CHIRP_2_ = "Google STT V2 (Chirp 2)"
    DEEPGRAM_NOVA_3 = "Deepgram Nova 3"
    GOOGLE_STT_V2 = "Google STT V2"
    GOOGLE_STT_V1 = "Google STT V1"
    DEEPGRAM_NOVA_2 = "Deepgram Nova 2"
