"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from syllable_sdk.types import BaseModel
from typing_extensions import TypedDict


class TwilioNumberUpdateRequestTypedDict(TypedDict):
    r"""Request model for updating a Twilio number and associating it with a channel."""

    friendly_name: str
    r"""Friendly name for the Twilio number"""
    phone_sid: str
    r"""Twilio number SID"""


class TwilioNumberUpdateRequest(BaseModel):
    r"""Request model for updating a Twilio number and associating it with a channel."""

    friendly_name: str
    r"""Friendly name for the Twilio number"""

    phone_sid: str
    r"""Twilio number SID"""
