"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .agenttoolfielddefault import AgentToolFieldDefault, AgentToolFieldDefaultTypedDict
from syllable_sdk.types import BaseModel
from typing import List
from typing_extensions import TypedDict


class AgentToolDefaultsTypedDict(TypedDict):
    r"""Agent-level static parameter values for a tool, overriding any tool-level defaults."""

    tool_name: str
    r"""The name of the tool"""
    default_values: List[AgentToolFieldDefaultTypedDict]
    r"""The default values for fields used in the tool"""


class AgentToolDefaults(BaseModel):
    r"""Agent-level static parameter values for a tool, overriding any tool-level defaults."""

    tool_name: str
    r"""The name of the tool"""

    default_values: List[AgentToolFieldDefault]
    r"""The default values for fields used in the tool"""
