"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class AgentVoiceGender(str, Enum):
    r"""Gender for an agent voice."""

    FEMALE = "female"
    MALE = "male"
