"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class AgentVoiceVarName(str, Enum):
    r"""The variable name of an agent voice (used when processing messages)."""

    OPENAI_ALLOY = "openai:alloy"
    OPENAI_ASH = "openai:ash"
    OPENAI_CORAL = "openai:coral"
    OPENAI_ECHO = "openai:echo"
    OPENAI_FABLE = "openai:fable"
    OPENAI_NOVA = "openai:nova"
    OPENAI_ONYX = "openai:onyx"
    OPENAI_SAGE = "openai:sage"
    OPENAI_SHIMMER = "openai:shimmer"
    ELEVENLABS_ALICE = "elevenlabs:Alice"
    ELEVENLABS_BILL = "elevenlabs:Bill"
    ELEVENLABS_BRIAN = "elevenlabs:Brian"
    ELEVENLABS_CALLUM = "elevenlabs:Callum"
    ELEVENLABS_CHARLIE = "elevenlabs:Charlie"
    ELEVENLABS_CHARLOTTE = "elevenlabs:Charlotte"
    ELEVENLABS_CHRIS = "elevenlabs:Chris"
    ELEVENLABS_DANIEL = "elevenlabs:Daniel"
    ELEVENLABS_ERIC = "elevenlabs:Eric"
    ELEVENLABS_GEORGE = "elevenlabs:George"
    ELEVENLABS_JESSICA = "elevenlabs:Jessica"
    ELEVENLABS_LAURA = "elevenlabs:Laura"
    ELEVENLABS_LIAM = "elevenlabs:Liam"
    ELEVENLABS_LILY = "elevenlabs:Lily"
    ELEVENLABS_MATILDA = "elevenlabs:Matilda"
    ELEVENLABS_RIVER = "elevenlabs:River"
    ELEVENLABS_ROGER = "elevenlabs:Roger"
    ELEVENLABS_SARAH = "elevenlabs:Sarah"
    ELEVENLABS_WILL = "elevenlabs:Will"
    WAVENET_FEMALE_EN_US_CHIRP3_HD_ACHERNAR = "wavenet:female/en-US-Chirp3-HD-Achernar"
    WAVENET_FEMALE_KO_KR_CHIRP3_HD_ACHERNAR = "wavenet:female/ko-KR-Chirp3-HD-Achernar"
    WAVENET_FEMALE_CMN_CN_CHIRP3_HD_ACHERNAR = (
        "wavenet:female/cmn-CN-Chirp3-HD-Achernar"
    )
    WAVENET_FEMALE_ES_US_CHIRP3_HD_ACHERNAR = "wavenet:female/es-US-Chirp3-HD-Achernar"
    WAVENET_FEMALE_TH_TH_CHIRP3_HD_ACHERNAR = "wavenet:female/th-TH-Chirp3-HD-Achernar"
    WAVENET_FEMALE_VI_VN_CHIRP3_HD_ACHERNAR = "wavenet:female/vi-VN-Chirp3-HD-Achernar"
    WAVENET_FEMALE_EN_US_CHIRP3_HD_AOEDE = "wavenet:female/en-US-Chirp3-HD-Aoede"
    WAVENET_FEMALE_KO_KR_CHIRP3_HD_AOEDE = "wavenet:female/ko-KR-Chirp3-HD-Aoede"
    WAVENET_FEMALE_CMN_CN_CHIRP3_HD_AOEDE = "wavenet:female/cmn-CN-Chirp3-HD-Aoede"
    WAVENET_FEMALE_ES_US_CHIRP3_HD_AOEDE = "wavenet:female/es-US-Chirp3-HD-Aoede"
    WAVENET_FEMALE_TH_TH_CHIRP3_HD_AOEDE = "wavenet:female/th-TH-Chirp3-HD-Aoede"
    WAVENET_FEMALE_VI_VN_CHIRP3_HD_AOEDE = "wavenet:female/vi-VN-Chirp3-HD-Aoede"
    WAVENET_MALE_ES_US_NEURAL2_B = "wavenet:male/es-US-Neural2-B"
    WAVENET_FEMALE_EN_US_CHIRP3_HD_CALLIRRHOE = (
        "wavenet:female/en-US-Chirp3-HD-Callirrhoe"
    )
    WAVENET_FEMALE_KO_KR_CHIRP3_HD_CALLIRRHOE = (
        "wavenet:female/ko-KR-Chirp3-HD-Callirrhoe"
    )
    WAVENET_FEMALE_CMN_CN_CHIRP3_HD_CALLIRRHOE = (
        "wavenet:female/cmn-CN-Chirp3-HD-Callirrhoe"
    )
    WAVENET_FEMALE_ES_US_CHIRP3_HD_CALLIRRHOE = (
        "wavenet:female/es-US-Chirp3-HD-Callirrhoe"
    )
    WAVENET_FEMALE_TH_TH_CHIRP3_HD_CALLIRRHOE = (
        "wavenet:female/th-TH-Chirp3-HD-Callirrhoe"
    )
    WAVENET_FEMALE_VI_VN_CHIRP3_HD_CALLIRRHOE = (
        "wavenet:female/vi-VN-Chirp3-HD-Callirrhoe"
    )
    WAVENET_MALE_EN_US_CHIRP3_HD_CHARON = "wavenet:male/en-US-Chirp3-HD-Charon"
    WAVENET_MALE_KO_KR_CHIRP3_HD_CHARON = "wavenet:male/ko-KR-Chirp3-HD-Charon"
    WAVENET_MALE_CMN_CN_CHIRP3_HD_CHARON = "wavenet:male/cmn-CN-Chirp3-HD-Charon"
    WAVENET_MALE_ES_US_CHIRP3_HD_CHARON = "wavenet:male/es-US-Chirp3-HD-Charon"
    WAVENET_MALE_TH_TH_CHIRP3_HD_CHARON = "wavenet:male/th-TH-Chirp3-HD-Charon"
    WAVENET_MALE_VI_VN_CHIRP3_HD_CHARON = "wavenet:male/vi-VN-Chirp3-HD-Charon"
    WAVENET_FEMALE_EN_US_NEURAL2_F = "wavenet:female/en-US-Neural2-F"
    WAVENET_MALE_EN_US_CHIRP3_HD_FENRIR = "wavenet:male/en-US-Chirp3-HD-Fenrir"
    WAVENET_MALE_KO_KR_CHIRP3_HD_FENRIR = "wavenet:male/ko-KR-Chirp3-HD-Fenrir"
    WAVENET_MALE_CMN_CN_CHIRP3_HD_FENRIR = "wavenet:male/cmn-CN-Chirp3-HD-Fenrir"
    WAVENET_MALE_ES_US_CHIRP3_HD_FENRIR = "wavenet:male/es-US-Chirp3-HD-Fenrir"
    WAVENET_MALE_TH_TH_CHIRP3_HD_FENRIR = "wavenet:male/th-TH-Chirp3-HD-Fenrir"
    WAVENET_MALE_VI_VN_CHIRP3_HD_FENRIR = "wavenet:male/vi-VN-Chirp3-HD-Fenrir"
    WAVENET_FEMALE_ES_US_NEURAL2_A = "wavenet:female/es-US-Neural2-A"
    WAVENET_MALE_EN_US_NEURAL2_D = "wavenet:male/en-US-Neural2-D"
    WAVENET_FEMALE_EN_US_CHIRP3_HD_KORE = "wavenet:female/en-US-Chirp3-HD-Kore"
    WAVENET_FEMALE_KO_KR_CHIRP3_HD_KORE = "wavenet:female/ko-KR-Chirp3-HD-Kore"
    WAVENET_FEMALE_CMN_CN_CHIRP3_HD_KORE = "wavenet:female/cmn-CN-Chirp3-HD-Kore"
    WAVENET_FEMALE_ES_US_CHIRP3_HD_KORE = "wavenet:female/es-US-Chirp3-HD-Kore"
    WAVENET_FEMALE_TH_TH_CHIRP3_HD_KORE = "wavenet:female/th-TH-Chirp3-HD-Kore"
    WAVENET_FEMALE_VI_VN_CHIRP3_HD_KORE = "wavenet:female/vi-VN-Chirp3-HD-Kore"
    WAVENET_FEMALE_EN_US_CHIRP3_HD_LEDA = "wavenet:female/en-US-Chirp3-HD-Leda"
    WAVENET_FEMALE_KO_KR_CHIRP3_HD_LEDA = "wavenet:female/ko-KR-Chirp3-HD-Leda"
    WAVENET_FEMALE_CMN_CN_CHIRP3_HD_LEDA = "wavenet:female/cmn-CN-Chirp3-HD-Leda"
    WAVENET_FEMALE_ES_US_CHIRP3_HD_LEDA = "wavenet:female/es-US-Chirp3-HD-Leda"
    WAVENET_FEMALE_TH_TH_CHIRP3_HD_LEDA = "wavenet:female/th-TH-Chirp3-HD-Leda"
    WAVENET_FEMALE_VI_VN_CHIRP3_HD_LEDA = "wavenet:female/vi-VN-Chirp3-HD-Leda"
    WAVENET_FEMALE_CMN_TW_WAVENET_A = "wavenet:female/cmn-TW-Wavenet-A"
    WAVENET_MALE_EN_US_NEURAL2_J = "wavenet:male/en-US-Neural2-J"
    WAVENET_FEMALE_YUE_HK_STANDARD_C = "wavenet:female/yue-HK-Standard-C"
    WAVENET_FEMALE_EN_US_STUDIO_O = "wavenet:female/en-US-Studio-O"
    WAVENET_MALE_EN_US_CHIRP3_HD_ORUS = "wavenet:male/en-US-Chirp3-HD-Orus"
    WAVENET_MALE_KO_KR_CHIRP3_HD_ORUS = "wavenet:male/ko-KR-Chirp3-HD-Orus"
    WAVENET_MALE_CMN_CN_CHIRP3_HD_ORUS = "wavenet:male/cmn-CN-Chirp3-HD-Orus"
    WAVENET_MALE_ES_US_CHIRP3_HD_ORUS = "wavenet:male/es-US-Chirp3-HD-Orus"
    WAVENET_MALE_TH_TH_CHIRP3_HD_ORUS = "wavenet:male/th-TH-Chirp3-HD-Orus"
    WAVENET_MALE_VI_VN_CHIRP3_HD_ORUS = "wavenet:male/vi-VN-Chirp3-HD-Orus"
    WAVENET_MALE_EN_US_CHIRP3_HD_PUCK = "wavenet:male/en-US-Chirp3-HD-Puck"
    WAVENET_MALE_KO_KR_CHIRP3_HD_PUCK = "wavenet:male/ko-KR-Chirp3-HD-Puck"
    WAVENET_MALE_CMN_CN_CHIRP3_HD_PUCK = "wavenet:male/cmn-CN-Chirp3-HD-Puck"
    WAVENET_MALE_ES_US_CHIRP3_HD_PUCK = "wavenet:male/es-US-Chirp3-HD-Puck"
    WAVENET_MALE_TH_TH_CHIRP3_HD_PUCK = "wavenet:male/th-TH-Chirp3-HD-Puck"
    WAVENET_MALE_VI_VN_CHIRP3_HD_PUCK = "wavenet:male/vi-VN-Chirp3-HD-Puck"
    WAVENET_FEMALE_KO_KR_NEURAL2_A = "wavenet:female/ko-KR-Neural2-A"
    WAVENET_FEMALE_VI_VN_NEURAL2_A = "wavenet:female/vi-VN-Neural2-A"
    WAVENET_MALE_EN_US_CHIRP3_HD_UMBRIEL = "wavenet:male/en-US-Chirp3-HD-Umbriel"
    WAVENET_MALE_KO_KR_CHIRP3_HD_UMBRIEL = "wavenet:male/ko-KR-Chirp3-HD-Umbriel"
    WAVENET_MALE_CMN_CN_CHIRP3_HD_UMBRIEL = "wavenet:male/cmn-CN-Chirp3-HD-Umbriel"
    WAVENET_MALE_ES_US_CHIRP3_HD_UMBRIEL = "wavenet:male/es-US-Chirp3-HD-Umbriel"
    WAVENET_MALE_TH_TH_CHIRP3_HD_UMBRIEL = "wavenet:male/th-TH-Chirp3-HD-Umbriel"
    WAVENET_MALE_VI_VN_CHIRP3_HD_UMBRIEL = "wavenet:male/vi-VN-Chirp3-HD-Umbriel"
    WAVENET_FEMALE_EN_US_CHIRP3_HD_VINDEMIATRIX = (
        "wavenet:female/en-US-Chirp3-HD-Vindemiatrix"
    )
    WAVENET_FEMALE_KO_KR_CHIRP3_HD_VINDEMIATRIX = (
        "wavenet:female/ko-KR-Chirp3-HD-Vindemiatrix"
    )
    WAVENET_FEMALE_CMN_CN_CHIRP3_HD_VINDEMIATRIX = (
        "wavenet:female/cmn-CN-Chirp3-HD-Vindemiatrix"
    )
    WAVENET_FEMALE_ES_US_CHIRP3_HD_VINDEMIATRIX = (
        "wavenet:female/es-US-Chirp3-HD-Vindemiatrix"
    )
    WAVENET_FEMALE_TH_TH_CHIRP3_HD_VINDEMIATRIX = (
        "wavenet:female/th-TH-Chirp3-HD-Vindemiatrix"
    )
    WAVENET_FEMALE_VI_VN_CHIRP3_HD_VINDEMIATRIX = (
        "wavenet:female/vi-VN-Chirp3-HD-Vindemiatrix"
    )
    WAVENET_FEMALE_EN_US_CHIRP3_HD_ZEPHYR = "wavenet:female/en-US-Chirp3-HD-Zephyr"
    WAVENET_FEMALE_KO_KR_CHIRP3_HD_ZEPHYR = "wavenet:female/ko-KR-Chirp3-HD-Zephyr"
    WAVENET_FEMALE_CMN_CN_CHIRP3_HD_ZEPHYR = "wavenet:female/cmn-CN-Chirp3-HD-Zephyr"
    WAVENET_FEMALE_ES_US_CHIRP3_HD_ZEPHYR = "wavenet:female/es-US-Chirp3-HD-Zephyr"
    WAVENET_FEMALE_TH_TH_CHIRP3_HD_ZEPHYR = "wavenet:female/th-TH-Chirp3-HD-Zephyr"
    WAVENET_FEMALE_VI_VN_CHIRP3_HD_ZEPHYR = "wavenet:female/vi-VN-Chirp3-HD-Zephyr"
