"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class LatencyCategory(str, Enum):
    TTS = "tts"
    STT = "stt"
    LLM = "llm"
    TOOL = "tool"
    HTTP = "http"
