"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from syllable_sdk.types import BaseModel
from typing_extensions import TypedDict


class TwilioPhoneNumberTypedDict(TypedDict):
    sid: str
    r"""The unique identifier for the phone number."""
    phone_number: str
    r"""The phone number."""
    friendly_name: str
    r"""A user-friendly name for the number."""
    trunk_sid: str
    r"""Associated trunk SID, if any."""


class TwilioPhoneNumber(BaseModel):
    sid: str
    r"""The unique identifier for the phone number."""

    phone_number: str
    r"""The phone number."""

    friendly_name: str
    r"""A user-friendly name for the number."""

    trunk_sid: str
    r"""Associated trunk SID, if any."""
