"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from syllable_sdk.types import BaseModel
from typing_extensions import TypedDict


class DashboardResponseTypedDict(TypedDict):
    r"""Basic information about a dashboard with a description."""

    name: str
    r"""Name of the dashboard"""
    display_name: str
    r"""Display name of the dashboard"""
    rank: int
    r"""Dashboard importance (0 is the highest)"""
    label: str
    r"""Dashboard label. Typically \"report\" or \"dashboard\" """


class DashboardResponse(BaseModel):
    r"""Basic information about a dashboard with a description."""

    name: str
    r"""Name of the dashboard"""

    display_name: str
    r"""Display name of the dashboard"""

    rank: int
    r"""Dashboard importance (0 is the highest)"""

    label: str
    r"""Dashboard label. Typically \"report\" or \"dashboard\" """
