"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from syllable_sdk.types import BaseModel
from syllable_sdk.utils import FieldMetadata, PathParamMetadata, QueryParamMetadata
from typing_extensions import Annotated, TypedDict


class ServiceDeleteRequestTypedDict(TypedDict):
    service_id: int
    reason: str


class ServiceDeleteRequest(BaseModel):
    service_id: Annotated[
        int, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]

    reason: Annotated[
        str, FieldMetadata(query=QueryParamMetadata(style="form", explode=True))
    ]
