"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .languagecode import LanguageCode
from syllable_sdk.types import BaseModel
from typing_extensions import TypedDict


class AgentLanguageTypedDict(TypedDict):
    r"""Language option for an agent."""

    name: str
    r"""Name of the language"""
    code: LanguageCode
    r"""BCP 47 codes of languages that Syllable supports."""


class AgentLanguage(BaseModel):
    r"""Language option for an agent."""

    name: str
    r"""Name of the language"""

    code: LanguageCode
    r"""BCP 47 codes of languages that Syllable supports."""
