"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from syllable_sdk.types import BaseModel
from typing import Any
from typing_extensions import TypedDict


class ToolResultDataTypedDict(TypedDict):
    tool_name: str
    r"""Tool name"""
    tool_result: Any
    r"""Tool result data"""


class ToolResultData(BaseModel):
    tool_name: str
    r"""Tool name"""

    tool_result: Any
    r"""Tool result data"""
