"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class LanguageCode(str, Enum):
    r"""BCP 47 codes of languages that Syllable supports."""

    YUE_HK = "yue-HK"
    EN_US = "en-US"
    KO_KR = "ko-KR"
    ZH_CN = "zh-CN"
    FA_IR = "fa-IR"
    ES_US = "es-US"
    TH_TH = "th-TH"
    VI_VN = "vi-VN"
    BS_BA = "bs-BA"
    SW_KE = "sw-KE"
