"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class DashboardProperties(str, Enum):
    r"""Names of dashboard fields supported for filtering/sorting on list endpoint."""

    ID = "id"
    NAME = "name"
    DISPLAY_NAME = "display_name"
    RANK = "rank"
    LABEL = "label"
