"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class ChannelTargetProperties(str, Enum):
    r"""Names of channel target fields supported for filtering/sorting on full channel targets list
    endpoint.
    """

    ID = "id"
    CHANNEL_ID = "channel_id"
    CHANNEL_NAME = "channel_name"
    AGENT_ID = "agent_id"
    TARGET = "target"
    TARGET_MODE = "target_mode"
    FALLBACK_TARGET = "fallback_target"
    IS_TEST = "is_test"
    UPDATED_AT = "updated_at"
