"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .twilionumberupdaterequest import (
    TwilioNumberUpdateRequest,
    TwilioNumberUpdateRequestTypedDict,
)
from syllable_sdk.types import BaseModel
from syllable_sdk.utils import FieldMetadata, PathParamMetadata, RequestMetadata
from typing_extensions import Annotated, TypedDict


class ChannelsTwilioNumbersUpdateRequestTypedDict(TypedDict):
    channel_id: int
    twilio_number_update_request: TwilioNumberUpdateRequestTypedDict


class ChannelsTwilioNumbersUpdateRequest(BaseModel):
    channel_id: Annotated[
        int, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]

    twilio_number_update_request: Annotated[
        TwilioNumberUpdateRequest,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]
