"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from syllable_sdk.types import BaseModel
from typing_extensions import TypedDict


class ToolAgentInfoTypedDict(TypedDict):
    r"""Information about an agent linked to a tool via a prompt."""

    id: int
    r"""The internal ID of the agent"""
    name: str
    r"""The name of the agent"""


class ToolAgentInfo(BaseModel):
    r"""Information about an agent linked to a tool via a prompt."""

    id: int
    r"""The internal ID of the agent"""

    name: str
    r"""The name of the agent"""
