"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class UserActivityStatus(str, Enum):
    NOT_INVITED = "not_invited"
    INVITED = "invited"
    ACTIVE = "active"
