"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class DayOfWeek(str, Enum):
    r"""Available options for day of the week for use in message rules."""

    MO = "mo"
    TU = "tu"
    WE = "we"
    TH = "th"
    FR = "fr"
    SA = "sa"
    SU = "su"
